@@ -1,6 +1,7 @@
-/* gEDA - GPL Electronic Design Automation
- * gattrib -- gEDA component and net attribute manipulation using spreadsheet.
+/* Lepton EDA attribute editor
  * Copyright (C) 2003-2010 Stuart D. Brorson.
+ * Copyright (C) 2003-2013 gEDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -120,7 +121,8 @@ void s_string_list_add_item(STRING_LIST *list, int *count, char *item) {
   STRING_LIST *local_list;
   
   if (list == NULL) {
-    fprintf(stderr, _("In s_string_list_add_item, tried to add to a NULL list.\n"));
+    fprintf (stderr, "s_string_list_add_item: ");
+    fprintf (stderr, _("Tried to add to a NULL list.\n"));
     return;
   }
 
@@ -128,7 +130,8 @@ void s_string_list_add_item(STRING_LIST *list, int *count, char *item) {
      into empty list separately.  (Is this necessary?) */
   if (list->data == NULL) {
 #ifdef DEBUG
-    printf("In s_string_list_add_item, about to place first item in list.\n");
+    printf ("s_string_list_add_item: ");
+    printf ("About to place first item in list.\n");
 #endif
     list->data = (gchar *) g_strdup(item);
     list->next = NULL;
@@ -185,12 +188,14 @@ void s_string_list_delete_item(STRING_LIST **list, int *count, gchar *item) {
 
   /* First check to see if list is empty.  If empty, spew error and return */
   if ( (*list)->data == NULL) {
-    fprintf(stderr, _("In s_string_list_delete_item, tried to remove item from empty list\n"));
+    fprintf (stderr, "s_string_list_delete_item: ");
+    fprintf (stderr, _("Tried to remove item from empty list.\n"));
     return;
   }
 
 #ifdef DEBUG
-    printf("In s_string_list_delete_item, about to delete item %s from list.\n", item);
+    printf ("s_string_list_delete_item: ");
+    printf ("About to delete item %s from list.\n", item);
 #endif
 
   /* Now loop through list looking for item */
@@ -198,12 +203,14 @@ void s_string_list_delete_item(STRING_LIST **list, int *count, gchar *item) {
   while (list_item != NULL) {
     trial_item = (gchar *) g_strdup(list_item->data);        
 #ifdef DEBUG
-    printf("In s_string_list_delete_item, matching item against trial item = %s from list.\n", trial_item);
+    printf ("s_string_list_delete_item: ");
+    printf ("Matching item against trial item = %s from list.\n", trial_item);
 #endif
     if (strcmp(trial_item, item) == 0) {
       /* found item, now delete it. */
 #ifdef DEBUG
-    printf("In s_string_list_delete_item, found match . . . . . \n");
+    printf ("s_string_list_delete_item: ");
+    printf ("Match found.\n");
 #endif
       prev_item = list_item->prev;
       next_item = list_item->next;
@@ -227,18 +234,21 @@ void s_string_list_delete_item(STRING_LIST **list, int *count, gchar *item) {
       }
       
 #ifdef DEBUG
-    printf("In s_string_list_delete_item, now free list_item\n");
+    printf ("s_string_list_delete_item: ");
+    printf ("Free list_item.\n");
 #endif
       g_free(list_item);  /* free current list item */
       (*count)--;       /* decrement count */
       /* Do we need to re-number the list? */
 
 #ifdef DEBUG
-    printf("In s_string_list_delete_item, now free trial_item\n");
+    printf ("s_string_list_delete_item: ");
+    printf ("Free trial_item.\n");
 #endif
       g_free(trial_item); /* free trial item before returning */
 #ifdef DEBUG
-    printf("In s_string_list_delete_item, returning . . . .\n");
+    printf ("s_string_list_delete_item: ");
+    printf ("Return.\n");
 #endif
       return;
     }
@@ -249,7 +259,8 @@ void s_string_list_delete_item(STRING_LIST **list, int *count, gchar *item) {
   /* If we are here, it's 'cause we didn't find the item.
    * Spew error and return.
    */
-  fprintf(stderr, _("In s_string_list_delete_item, couldn't delete item %s\n"), item);
+  fprintf (stderr, "s_string_list_delete_item:");
+  fprintf (stderr, _("Couldn't delete item %1$s\n"), item);
   return;
 
 }
