@@ -1,10 +1,6 @@
-extern char *default_bitmap_directory;
-extern char *default_bus_ripper_symname;
-
-extern GPtrArray *default_always_promote_attributes;
-
 extern int default_attribute_promotion;
 extern int default_promote_invisible;
 extern int default_keep_invisible;
 
 extern int default_make_backup_files;
+extern int default_net_consolidate;
