@@ -2,7 +2,7 @@
  * Copyright (C) 1998, 1999, 2000 Kazu Hirata / Ales Hvezda
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,8 +31,6 @@ struct st_toplevel
 
   GList *RC_list;                       /* List of RC files which have been read in. */
 
-  char *bitmap_directory; 		/* path of the bitmaps */
-
   int init_left, init_right; 		/* Starting values for above */
   int init_top, init_bottom;
 
@@ -53,30 +51,9 @@ struct st_toplevel
   int auto_save_interval;
   gint auto_save_timeout;
 
-  /* controls if the net consolidation code is used */
-  int net_consolidate;
-
-  /*controls if attribute promotion happens */
-  int attribute_promotion;
-
-  /* controls if invisible attribs are promoted */
-  int promote_invisible;
-
-  /* controls if invisible attribs are kept and not deleted */
-  int keep_invisible;
-
-  /* controls the generation of backup (~) files */
-  int make_backup_files;
-
-  /* filename of the bus ripper component if set above */
-  char *bus_ripper_symname;
-
   /* controls if the whole bounding box is used in the auto whichend code */
   int force_boundingbox;
 
-  /* List of attributes to always promote */
-  GPtrArray *always_promote_attributes;
-
   /* Callback function for calculating text bounds */
   RenderedBoundsFunc rendered_text_bounds_func;
   void *rendered_text_bounds_data;
