@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2018 Lepton EDA Contributors
+ * Copyright (C) 2017-2019 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,10 +26,11 @@
 #ifndef _GLOBALS_H_INCL
 #define _GLOBALS_H_INCL
 
+extern gboolean config_legacy_mode;
+
 extern int verbose_loading;
 
 extern int do_logging;
-extern int logging_dest;
 
 /* Size of a tab in characters */
 extern int tab_in_chars;
