@@ -1,6 +1,7 @@
-/* gEDA - GPL Electronic Design Automation
- * libgeda - gEDA's Library
+/* Lepton EDA library
  * Copyright (C) 1998-2012 Ales Hvezda
+ * Copyright (C) 1998-2015 gEDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -45,7 +46,7 @@ G_BEGIN_DECLS
 #include <liblepton/geda_bounds.h>
 #include <liblepton/geda_box.h>
 #include <liblepton/geda_circle.h>
-#include <liblepton/geda_complex.h>
+#include <liblepton/geda_component.h>
 #include <liblepton/geda_coord.h>
 #include <liblepton/geda_line.h>
 #include <liblepton/geda_path.h>
@@ -66,7 +67,7 @@ G_BEGIN_DECLS
 #include <liblepton/geda_box_object.h>
 #include <liblepton/geda_bus_object.h>
 #include <liblepton/geda_circle_object.h>
-#include <liblepton/geda_complex_object.h>
+#include <liblepton/geda_component_object.h>
 #include <liblepton/geda_line_object.h>
 #include <liblepton/geda_net_object.h>
 #include <liblepton/geda_path_object.h>
