@@ -1,6 +1,4 @@
 /* g_rc.c */
-int vstbl_lookup_str(const vstbl_entry *table, int size, const char *str);
-int vstbl_get_val(const vstbl_entry *table, int index);
 SCM scheme_directory(SCM s_path);
 
 /* g_register.c */
@@ -22,8 +20,7 @@ GList *o_read_attribs(TOPLEVEL *toplevel,
                       unsigned int fileformat_ver, GError **err);
 OBJECT *o_attrib_find_attrib_by_name (const GList *list, const char *name, int count);
 
-/* o_basic.c */
-void o_bounds_invalidate(TOPLEVEL *toplevel, OBJECT *object);
+/* geda_object.c */
 void o_emit_pre_change_notify(TOPLEVEL *toplevel, OBJECT *object);
 void o_emit_change_notify(TOPLEVEL *toplevel, OBJECT *object);
 
