@@ -1,7 +1,7 @@
 ;; Lepton EDA library - Scheme API
 ;; Copyright (C) 2012 Peter Brett <peter@peter-b.co.uk>
 ;; Copyright (C) 2016 gEDA Contributors
-;; Copyright (C) 2017-2019 Lepton EDA Contributors
+;; Copyright (C) 2017-2020 Lepton EDA Contributors
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -30,22 +30,20 @@
 ;; Utility functions and macros
 ;; ===================================================================
 
+
+( use-modules ( lepton config ) )
+( use-modules ( lepton legacy-config ) )
+
+
 ;; Returns an RC function closure to replace the legacy configuration
 ;; function OLD-ID.  The returned closure takes an arbitrary number of
 ;; arguments, and does nothing other than print a deprecation message
 ;; the first time it is called.
 (define (rc-dead-config old-id)
-  ;; FIXME more helpful error message with link to documentation.
-  (define (deprecation-warning)
-    (format (current-error-port)
-"
-WARNING: The RC file function '~A' is deprecated
-and does nothing.
-RC configuration functions will be removed in an upcoming Lepton EDA
-release. Please use .conf configuration files instead:
-https://github.com/lepton-eda/lepton-eda/wiki/Configuration-Settings
 
-" old-id))
+  (define (deprecation-warning)
+    (display (warning-option-obsolete old-id) (current-error-port)))
+
   (let ((warned? #f))
     (lambda args
       (or warned? (begin (deprecation-warning) (set! warned? #t))))))
@@ -67,30 +65,24 @@ https://github.com/lepton-eda/lepton-eda/wiki/Configuration-Settings
 ;; VALUE-TRANSFORMER.  The first time the closure is called, it prints
 ;; a deprecation message.
 (define (rc-deprecated-config old-id group key value-transformer)
-  ;; FIXME more helpful error message with link to documentation.
+
   (define (deprecation-warning)
-    (format (current-error-port)
-"
-WARNING: The RC file function '~A' is deprecated.
-RC configuration functions will be removed in an upcoming Lepton EDA
-release. Please use .conf configuration files instead:
-https://github.com/lepton-eda/lepton-eda/wiki/Configuration-Settings
+    (display (warning-option-deprecated old-id group key)
+             (current-error-port)))
 
-Put the following lines into the ~A file (in current directory)
-or ~A (in user's configuration directory, typically
-$HOME/.config/lepton-eda/), replacing MYVALUE with the desired
-option's value:
-
-[~A]
-~A=MYVALUE
-
-" old-id "geda.conf" "geda-user.conf" group key))
   (let ((warned? #f))
     (lambda args
       (or warned?
           (begin (deprecation-warning) (set! warned? #t)))
-      ((@ (geda config) set-config!)
-       (rc-config) group key (apply value-transformer args)))))
+      (set-config!
+        (path-config-context (getcwd))
+        group
+        key
+        (apply value-transformer args)
+      )
+    )
+  ) ; let
+)
 
 ;; Convenience macro for using rc-deprecated-config.
 ;;
@@ -108,6 +100,23 @@ option's value:
 ;; Identity value transformer for define-rc-deprecated-config
 (define (rc-deprecated-string-transformer str) str)
 
+(define (rc-deprecated-int-transformer num) num)
+
+; ( list "attr1" "attr2" "attr3" ) => "attr1;attr2;attr3":
+;
+( define ( rc-deprecated-strlist-transformer strlist )
+  ; return:
+  ( apply
+    string-append
+    ( map
+      ( lambda( str )
+        ( format #f "~a;" str )
+      )
+      strlist
+    )
+  )
+)
+
 ;; Transformer for "enabled"/"disabled" to boolean
 (define (rc-deprecated-string-boolean-transformer str)
   (string=? "enabled" str))
@@ -118,6 +127,22 @@ option's value:
 
 (define-rc-dead-config postscript-prolog)
 (define-rc-dead-config world-size)
+(define-rc-dead-config bitmap-directory)
+(define-rc-deprecated-config
+ attribute-promotion "schematic.attrib" "promote"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ promote-invisible "schematic.attrib" "promote-invisible"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ keep-invisible "schematic.attrib" "keep-invisible"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ make-backup-files "schematic.backup" "create-files"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ always-promote-attributes "schematic.attrib" "always-promote"
+ rc-deprecated-strlist-transformer)
 
 ;; ===================================================================
 ;; Deprecated lepton-schematic configuration functions
@@ -134,15 +159,15 @@ option's value:
 (define-rc-dead-config setpagedevice-pagesize)
 
 (define-rc-deprecated-config
- print-paper "gschem.printing" "paper"
+ print-paper "schematic.printing" "paper"
  rc-deprecated-string-transformer)
 
 (define-rc-deprecated-config
- print-orientation "gschem.printing" "layout"
+ print-orientation "schematic.printing" "layout"
  rc-deprecated-string-transformer)
 
 (define-rc-deprecated-config
- print-color "gschem.printing" "monochrome"
+ print-color "schematic.printing" "monochrome"
  (lambda (x) (not (rc-deprecated-string-boolean-transformer x))))
 
 (define-rc-dead-config net-style)
@@ -157,17 +182,17 @@ option's value:
 (define-rc-dead-config text-feedback)
 
 (define-rc-deprecated-config
- untitled-name "gschem" "default-filename"
+ untitled-name "schematic" "default-filename"
  rc-deprecated-string-transformer)
 
 (define-rc-dead-config scrollbar-update)
 
 (define-rc-deprecated-config
- sort-component-library "gschem.library" "sort"
+ sort-component-library "schematic.library" "sort"
  rc-deprecated-string-boolean-transformer)
 
 (define-rc-deprecated-config
- component-dialog-attributes "gschem.library" "component-attributes"
+ component-dialog-attributes "schematic.library" "component-attributes"
  (lambda (x) x))
 
 (define-rc-dead-config add-attribute-offset)
@@ -184,41 +209,180 @@ option's value:
 (define-rc-dead-config gnetlist-version)
 
 (define-rc-deprecated-config
-  unnamed-netname "gnetlist" "default-net-name"
+  unnamed-netname "netlist" "default-net-name"
   rc-deprecated-string-transformer)
 (define-rc-deprecated-config
-  unnamed-busname "gnetlist" "default-bus-name"
+  unnamed-busname "netlist" "default-bus-name"
   rc-deprecated-string-transformer)
 (define-rc-deprecated-config
-  net-naming-priority "gnetlist" "net-naming-priority"
+  net-naming-priority "netlist" "net-naming-priority"
   (lambda (x) (if (string=? x "netname") "netname-attribute" "net-attribute")))
 (define-rc-deprecated-config
-  hierarchy-traversal "gnetlist.hierarchy" "traverse-hierarchy"
+  hierarchy-traversal "netlist.hierarchy" "traverse-hierarchy"
   rc-deprecated-string-boolean-transformer)
 (define-rc-deprecated-config
-  hierarchy-uref-mangle "gnetlist.hierarchy" "mangle-refdes-attribute"
+  hierarchy-uref-mangle "netlist.hierarchy" "mangle-refdes-attribute"
   rc-deprecated-string-boolean-transformer)
 (define-rc-deprecated-config
-  hierarchy-uref-order "gnetlist.hierarchy" "refdes-attribute-order"
+  hierarchy-uref-order "netlist.hierarchy" "refdes-attribute-order"
   (lambda (x) (string=? "prepend" x)))
 (define-rc-deprecated-config
-  hierarchy-uref-separator "gnetlist.hierarchy" "refdes-attribute-separator"
+  hierarchy-uref-separator "netlist.hierarchy" "refdes-attribute-separator"
   rc-deprecated-string-transformer)
 (define-rc-deprecated-config
-  hierarchy-netname-mangle "gnetlist.hierarchy" "mangle-netname-attribute"
+  hierarchy-netname-mangle "netlist.hierarchy" "mangle-netname-attribute"
   rc-deprecated-string-boolean-transformer)
 (define-rc-deprecated-config
-  hierarchy-netname-order "gnetlist.hierarchy" "netname-attribute-order"
+  hierarchy-netname-order "netlist.hierarchy" "netname-attribute-order"
   (lambda (x) (string=? "prepend" x)))
 (define-rc-deprecated-config
-  hierarchy-netname-separator "gnetlist.hierarchy" "netname-attribute-separator"
+  hierarchy-netname-separator "netlist.hierarchy" "netname-attribute-separator"
   rc-deprecated-string-transformer)
 (define-rc-deprecated-config
-  hierarchy-netattrib-mangle "gnetlist.hierarchy" "mangle-net-attribute"
+  hierarchy-netattrib-mangle "netlist.hierarchy" "mangle-net-attribute"
   rc-deprecated-string-boolean-transformer)
 (define-rc-deprecated-config
-  hierarchy-netattrib-order "gnetlist.hierarchy" "net-attribute-order"
+  hierarchy-netattrib-order "netlist.hierarchy" "net-attribute-order"
   (lambda (x) (string=? "prepend" x)))
 (define-rc-deprecated-config
-  hierarchy-netattrib-separator "gnetlist.hierarchy" "net-attribute-separator"
+  hierarchy-netattrib-separator "netlist.hierarchy" "net-attribute-separator"
   rc-deprecated-string-transformer)
+
+(define-rc-deprecated-config
+ draw-grips "schematic.gui" "draw-grips"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ toolbars "schematic.gui" "toolbars"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ scrollbars "schematic.gui" "scrollbars"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ handleboxes "schematic.gui" "handleboxes"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ zoom-with-pan "schematic.gui" "zoom-with-pan"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ fast-mousepan "schematic.gui" "fast-mousepan"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ continue-component-place "schematic.gui" "continue-component-place"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ file-preview "schematic.gui" "file-preview"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ enforce-hierarchy "schematic.gui" "enforce-hierarchy"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ third-button-cancel "schematic.gui" "third-button-cancel"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ warp-cursor "schematic.gui" "warp-cursor"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ force-boundingbox "schematic.gui" "force-boundingbox"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ net-direction-mode "schematic.gui" "net-direction-mode"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ embed-components "schematic.gui" "embed-components"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ netconn-rubberband "schematic.gui" "netconn-rubberband"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ magnetic-net-mode "schematic.gui" "magnetic-net-mode"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ zoom-gain "schematic.gui" "zoom-gain"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ mousepan-gain "schematic.gui" "mousepan-gain"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ keyboardpan-gain "schematic.gui" "keyboardpan-gain"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ select-slack-pixels "schematic.gui" "select-slack-pixels"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ text-size "schematic.gui" "text-size"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ snap-size "schematic.gui" "snap-size"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ scrollpan-steps "schematic.gui" "scrollpan-steps"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ dots-grid-dot-size "schematic.gui" "dots-grid-dot-size"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ dots-grid-fixed-threshold "schematic.gui" "dots-grid-fixed-threshold"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ mesh-grid-display-threshold "schematic.gui" "mesh-grid-display-threshold"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ action-feedback-mode "schematic.gui" "action-feedback-mode"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ text-caps-style "schematic.gui" "text-caps-style"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ middle-button "schematic.gui" "middle-button"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ third-button "schematic.gui" "third-button"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ scroll-wheel "schematic.gui" "scroll-wheel"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ grid-mode "schematic.gui" "grid-mode"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ dots-grid-mode "schematic.gui" "dots-grid-mode"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ net-selection-mode "schematic.gui" "net-selection-mode"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ undo-control "schematic.undo" "undo-control"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ undo-type "schematic.undo" "undo-type"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ undo-levels "schematic.undo" "undo-levels"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ undo-panzoom "schematic.undo" "undo-panzoom"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ bus-ripper-size "schematic" "bus-ripper-size"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ bus-ripper-type "schematic" "bus-ripper-type"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ bus-ripper-rotation "schematic" "bus-ripper-rotation"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ net-consolidate "schematic" "net-consolidate"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ logging "schematic" "logging"
+ rc-deprecated-string-boolean-transformer)
+(define-rc-deprecated-config
+ auto-save-interval "schematic" "auto-save-interval"
+ rc-deprecated-int-transformer)
+(define-rc-deprecated-config
+ log-window "schematic" "log-window"
+ rc-deprecated-string-transformer)
+(define-rc-deprecated-config
+ bus-ripper-symname "schematic" "bus-ripper-symname"
+ rc-deprecated-string-transformer)
