@@ -1,12 +1,7 @@
-;; Test Scheme procedures defined in geda.scm.  Makes blatant
-;; assumptions about the current directory.  Oh well.
-
 (use-modules (unit-test)
              (lepton file-system)
              (lepton rc))
 
-(load-from-path "geda.scm")
-
 (begin-test 'build-path
  (assert-equal
   "prefix/suffix"
@@ -15,6 +10,8 @@
   "/path/to/a/directory"
   (build-path "/path" "to" "a" "directory")))
 
+; Makes blatant assumptions about the current directory. Oh well:
+;
 (begin-test 'regular-file?
  (assert-true (regular-file? "Makefile"))
  (assert-true (not (regular-file? "."))))
