@@ -1,7 +1,7 @@
-/* gEDA - GPL Electronic Design Automation
- * libgeda - gEDA's library
+/* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2010 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2014 gEDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,6 +51,7 @@
 
 #include "libgeda_priv.h"
 
+
 /*! \brief Get the autosave filename for a file
  *  \par Function description
  *  Returns the expected autosave filename for the \a filename passed.
@@ -358,6 +359,10 @@ int f_save(TOPLEVEL *toplevel, PAGE *page, const char *filename, GError **err)
   mode_t saved_umask, mask;
   struct stat st;
   GError *tmp_err = NULL;
+  gboolean make_backup_files;
+
+  cfg_read_bool ("schematic.backup", "create-files",
+                 default_make_backup_files, &make_backup_files);
 
   /* Get the real filename and file permissions */
   real_filename = follow_symlinks (filename, &tmp_err);
@@ -384,7 +389,7 @@ int f_save(TOPLEVEL *toplevel, PAGE *page, const char *filename, GError **err)
 
   /* Do a backup if it's not an undo file backup and it was never saved.
    * Only do a backup if backup files are enabled */
-  if (page->saved_since_first_loaded == 0 && toplevel->make_backup_files == TRUE) {
+  if (page->saved_since_first_loaded == 0 && make_backup_files == TRUE) {
     if ( (g_file_test (real_filename, G_FILE_TEST_EXISTS)) && 
 	 (!g_file_test(real_filename, G_FILE_TEST_IS_DIR)) )
     {
@@ -452,7 +457,6 @@ int f_save(TOPLEVEL *toplevel, PAGE *page, const char *filename, GError **err)
     page->saved_since_first_loaded = 1;
 
     /* Reset the last saved timer */
-    g_get_current_time (&page->last_load_or_save_time);
     page->ops_since_last_backup = 0;
     page->do_autosave_backup = 0;
 
@@ -601,7 +605,7 @@ char *follow_symlinks (const gchar *filename, GError **err)
 
   /* Too many symlinks */
   g_set_error (err, G_FILE_ERROR, G_FILE_ERROR_LOOP,
-               _("%s: %s"), g_strerror (EMLINK), followed_filename);
+               "%s: %s", g_strerror (EMLINK), followed_filename);
   g_free (followed_filename);
   return NULL;
 
