@@ -2,7 +2,7 @@
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
  * Copyright (C) 2016 Peter Brett <peter@peter-b.co.uk>
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,71 +44,6 @@
 #include "libgeda_priv.h"
 #include "libgedaguile_priv.h"
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-int vstbl_lookup_str(const vstbl_entry *table,
-			    int size, const char *str)
-{
-  int i;
-
-  for(i = 0; i < size; i++) {
-    if(strcmp(table[i].m_str, str) == 0) {
-      break;
-    }
-  }
-  return i;
-}
-
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-int vstbl_get_val(const vstbl_entry *table, int index)
-{
-  return table[index].m_val;
-}
-
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM g_rc_mode_general(SCM scmmode, 
-                      const char *rc_name,
-                      int *mode_var,
-                      const vstbl_entry *table,
-                      int table_size)
-{
-  SCM ret;
-  int index;
-  char *mode;
-
-  SCM_ASSERT (scm_is_string (scmmode), scmmode,
-              SCM_ARG1, rc_name);
-  
-  mode = scm_to_utf8_string (scmmode);
-  
-  index = vstbl_lookup_str(table, table_size, mode);
-  /* no match? */
-  if(index == table_size) {
-    fprintf(stderr,
-            _("Invalid mode [%1$s] passed to %2$s\n"),
-            mode,
-            rc_name);
-    ret = SCM_BOOL_F;
-  } else {
-    *mode_var = vstbl_get_val(table, index);
-    ret = SCM_BOOL_T;
-  }
-
-  free (mode);
-
-  return ret;
-}
 
 /*! \brief Mark an RC file as loaded.
  * \par Function Description
@@ -675,25 +610,6 @@ g_rc_rc_filename()
   return scm_source_property (source, scm_sym_filename);
 }
 
-/*!
- * \brief Get a configuration context for the current RC file.
- * \par Function Description
- * Returns the configuration context applicable to the RC file being
- * evaluated.  This function is intended to support gEDA transition
- * from functions in RC files to static configuration files.
- *
- * \returns An EdaConfig smob.
- */
-SCM
-g_rc_rc_config()
-{
-  SCM cfg_s = scm_fluid_ref (scheme_rc_config_fluid);
-  if (!scm_is_false (cfg_s)) return cfg_s;
-
-  EdaConfig *cfg = eda_config_get_context_for_file (NULL);
-  return edascm_from_config (cfg);
-}
-
 /*! \brief Add a directory to the Guile load path.
  * \par Function Description
  * Prepends \a s_path to the Guile system '%load-path', after
@@ -730,76 +646,6 @@ SCM_DEFINE (scheme_directory,"%scheme-directory", 1, 0, 0,
   return SCM_BOOL_T;
 }
 
-/*! \todo Finish function description!!!
- *  \brief
- *  \par Function Description
- *
- *  \param [in] path  
- *  \return SCM_BOOL_T on success, SCM_BOOL_F otherwise.
- */
-
-SCM_DEFINE (bitmap_directory, "%bitmap-directory", 0, 1, 0,
-            (SCM s_path), "Set bitmap directory to retrieve pictures from.")
-{
-  if (scm_is_eq (s_path, SCM_UNDEFINED)) {
-    if (default_bitmap_directory != NULL) {
-      return scm_from_utf8_string (default_bitmap_directory);
-    } else {
-      return SCM_BOOL_F;
-    }
-  }
-
-  gchar *string;
-  char *temp;
-
-  SCM_ASSERT (scm_is_string (s_path), s_path,
-              SCM_ARG1, s_bitmap_directory);
-  
-  /* take care of any shell variables */
-  temp = scm_to_utf8_string (s_path);
-  string = s_expand_env_variables (temp);
-  free (temp);
-
-  /* invalid path? */
-  if (!g_file_test (string, G_FILE_TEST_IS_DIR)) {
-    fprintf (stderr,
-             _("Invalid path [%1$s] passed to bitmap-directory\n"),
-             string);
-    g_free(string);
-    return SCM_BOOL_F;
-  }
-
-  g_free(default_bitmap_directory);
-  default_bitmap_directory = string;
-
-  return SCM_BOOL_T;
-}
-
-/*! \todo Finish function description!!!
- *  \brief
- *  \par Function Description
- *
- *  \param [in] scmsymname  
- *  \return SCM_BOOL_T always.
- */
-SCM_DEFINE (bus_ripper_symname, "%bus-ripper-symname", 1, 0, 0,
-            (SCM scmsymname),
-            "Choose the name of a symbol which should represent bus-rippers in schematics.")
-{
-  char *temp;
-
-  SCM_ASSERT (scm_is_string (scmsymname), scmsymname,
-              SCM_ARG1, s_bus_ripper_symname);
-
-  g_free(default_bus_ripper_symname);
-
-  temp = scm_to_utf8_string (scmsymname);
-  default_bus_ripper_symname = g_strdup (temp);
-  free (temp);
-
-  return SCM_BOOL_T;
-}
-
 /*! \todo Finish function description!!!
  *  \brief
  *  \par Function Description
@@ -814,122 +660,6 @@ SCM_DEFINE (reset_component_library, "%reset-component-library", 0, 0, 0,
   return SCM_BOOL_T;
 }
 
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM_DEFINE (attribute_promotion, "%attribute-promotion", 0, 1, 0,
-            (SCM s_mode), "Set attribute promotion behaviour or return its state.")
-{
-  if (scm_is_eq (s_mode, SCM_UNDEFINED)) {
-    return scm_from_bool (default_attribute_promotion);
-  }
-
-  default_attribute_promotion = scm_is_true (s_mode);
-  return s_mode;
-}
-
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM_DEFINE (promote_invisible, "%promote-invisible", 0, 1, 0,
-            (SCM s_mode), "Set attribute promotion behaviour for invisible attributes or return its state.")
-{
-  if (scm_is_eq (s_mode, SCM_UNDEFINED)) {
-    return scm_from_bool (default_promote_invisible);
-  }
-
-  default_promote_invisible = scm_is_true (s_mode);
-  return s_mode;
-}
-
-/*! \todo Finish function documentation!!!
- *  \brief
- *  \par Function Description
- *
- */
-SCM_DEFINE (keep_invisible, "%keep-invisible", 0, 1, 0,
-            (SCM s_mode), "Controls or sets if invisible promoted attributes are not deleted.")
-{
-  if (scm_is_eq (s_mode, SCM_UNDEFINED)) {
-    return scm_from_bool (default_keep_invisible);
-  }
-
-  default_keep_invisible = scm_is_true (s_mode);
-  return s_mode;
-}
-
-/*! \todo Finish function description!!!
- *  \brief
- *  \par Function Description
- *
- *  \param [in] attrlist
- *  \return SCM_BOOL_T always.
- */
-SCM_DEFINE (always_promote_attributes, "%always-promote-attributes", 1, 0, 0,
-            (SCM attrlist),
-            "Set the list of attributes that are always promoted regardless of their visibility.")
-{
-  SCM_ASSERT (scm_is_true (scm_list_p (attrlist)), attrlist, SCM_ARG1,
-              s_always_promote_attributes);
-
-  if (default_always_promote_attributes) {
-    g_ptr_array_unref (default_always_promote_attributes);
-  }
-
-  GPtrArray *promote = g_ptr_array_new ();
-
-  scm_dynwind_begin ((scm_t_dynwind_flags) 0);
-  scm_dynwind_unwind_handler ((void (*)(void *)) g_ptr_array_unref,
-                              promote,
-                              (scm_t_wind_flags) 0);
-
-  for (SCM iter = attrlist; !scm_is_null(iter); iter = scm_cdr(iter))
-  {
-    SCM car = scm_car (iter);
-
-    if (scm_is_string (car))
-    {
-      char* attr = scm_to_utf8_string (car);
-
-      /* Only accept non-empty strings:
-      */
-      if (strlen (attr) > 0)
-      {
-        g_ptr_array_add (promote, (gpointer) g_intern_string (attr));
-      }
-
-      free (attr);
-    }
-
-  }
-
-  scm_dynwind_end();
-
-  default_always_promote_attributes = promote;
-
-  return SCM_BOOL_T;
-}
-
-/*! \brief Enable the creation of backup files when saving
- *  \par Function Description
- *  If enabled then a backup file, of the form 'example.sch~', is created when
- *  saving a file.
- *
- *  \param [in] s_mode  String. 'enabled' or 'disabled'
- *  \return           Bool. False if s_mode is not a valid value; true if it is.
- *
- */
-SCM_DEFINE (make_backup_files, "%make-backup-files", 1, 0, 0,
-            (SCM s_mode), "Enable or disable the creation of backup files.")
-{
-  default_make_backup_files = scm_is_true (s_mode);
-  return s_mode;
-}
-
 SCM_DEFINE (print_color_map, "%print-color-map", 0, 1, 0,
             (SCM scm_map), "Set or view current print color map.")
 {
@@ -992,17 +722,10 @@ init_module_lepton_core_rc (void *unused)
   #include "g_rc.x"
 
   /* Add them to the module's public definitions. */
-  scm_c_export (s_always_promote_attributes,
-                s_attribute_promotion,
-                s_bitmap_directory,
-                s_bus_ripper_symname,
-                s_component_library,
+  scm_c_export (s_component_library,
                 s_component_library_command,
                 s_component_library_funcs,
-                s_keep_invisible,
-                s_make_backup_files,
                 s_print_color_map,
-                s_promote_invisible,
                 s_reset_component_library,
                 s_scheme_directory,
                 NULL);
