@@ -1,7 +1,7 @@
-/* gEDA - GPL Electronic Design Automation
- * libgeda - gEDA's library
+/* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2010 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2016 gEDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -95,10 +95,6 @@ geda_arc_object_new (TOPLEVEL *toplevel,
   o_set_fill_options(toplevel, new_node,
                      FILLING_HOLLOW, -1, -1, -1, -1, -1);
 
-  new_node->w_bounds_valid_for = NULL;
-
-  /* new_node->graphical = arc; eventually */
-
   return new_node;
 }
 
@@ -353,7 +349,6 @@ geda_arc_object_modify (TOPLEVEL *toplevel, OBJECT *object, int x, int y, int wh
 	}
 
 	/* update the screen coords and the bounding box */
-	object->w_bounds_valid_for = NULL;
 	o_emit_change_notify (toplevel, object);
 }
 
@@ -426,7 +421,7 @@ OBJECT *o_arc_read (TOPLEVEL *toplevel, const char buf[],
   /* Error check */
   if (radius <= 0) {
     s_log_message (_("Found a zero radius arc "
-                     "[ %1$c %2$d, %3$d, %4$d, %5$d, %6$d, %7$d ]"),
+                     "[ %1$c %2$d %3$d %4$d %5$d %6$d %7$d ]"),
                    type, x1, y1, radius, start_angle, sweep_angle, color);
     radius = 0;
   }
@@ -515,10 +510,6 @@ geda_arc_object_translate (GedaObject *object, int dx, int dy)
   /* Do world coords */
   object->arc->x = object->arc->x + dx;
   object->arc->y = object->arc->y + dy;
-
-
-  /* Recalculate screen coords from new world coords */
-  object->w_bounds_valid_for = NULL;
 }
 
 /*! \brief
@@ -572,10 +563,6 @@ void geda_arc_object_rotate (TOPLEVEL *toplevel,
   /* translate object to its previous place */
   object->arc->x += world_centerx;
   object->arc->y += world_centery;
-
-  /* update the screen coords and the bounding box */
-  object->w_bounds_valid_for = NULL;
-
 }
 
 /*! \brief Mirror the WORLD coordinates of an ARC.
@@ -616,10 +603,6 @@ void geda_arc_object_mirror (TOPLEVEL *toplevel,
 
   /* translate object back to its previous position */
   object->arc->x += world_centerx;
-
-  /* update the screen coords and bounding box */
-  object->w_bounds_valid_for = NULL;
-
 }
 
 
