@@ -1,7 +1,7 @@
-/* gEDA - GPL Electronic Design Automation
- * libgeda - gEDA's library
+/* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2010 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2016 gEDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 
 #include "libgeda_priv.h"
 
+
 /*! \file o_net_basic.c
  *  \brief functions for the net object
  */
@@ -266,8 +267,6 @@ geda_net_object_new (TOPLEVEL *toplevel, char type,
   new_node->line->y[1] = y2;
   new_node->line_width = NET_WIDTH;
 
-  new_node->w_bounds_valid_for = NULL;
-
   return new_node;
 }
 
@@ -359,9 +358,6 @@ geda_net_object_translate (GedaObject *object, int dx, int dy)
   object->line->y[0] = object->line->y[0] + dy;
   object->line->x[1] = object->line->x[1] + dx;
   object->line->y[1] = object->line->y[1] + dy;
-
-  /* Update bounding box */
-  object->w_bounds_valid_for = NULL;
 }
 
 /*! \brief create a copy of a net object
@@ -628,7 +624,7 @@ static int o_net_consolidate_segments (TOPLEVEL *toplevel, OBJECT *object)
   g_return_val_if_fail ((object->type == OBJ_NET), 0);
 
   /* It's meaningless to do anything here if the object isn't in a page. */
-  page = o_get_page (toplevel, object);
+  page = o_get_page (object);
   g_return_val_if_fail ((page != NULL), 0);
 
   object_orient = geda_net_object_orientation (object);
@@ -671,7 +667,6 @@ static int o_net_consolidate_segments (TOPLEVEL *toplevel, OBJECT *object)
           }
 
           s_delete_object (toplevel, other_object);
-          object->w_bounds_valid_for = NULL;
           s_conn_update_object (page, object);
           return(-1);
         }
@@ -699,10 +694,17 @@ geda_net_object_consolidate (TOPLEVEL *toplevel, PAGE *page)
   OBJECT *o_current;
   const GList *iter;
   int status = 0;
+  gboolean net_consolidate;
 
   g_return_if_fail (toplevel != NULL);
   g_return_if_fail (page != NULL);
 
+  cfg_read_bool ("schematic", "net-consolidate",
+                 default_net_consolidate, &net_consolidate);
+
+  if (!net_consolidate)
+    return;
+
   iter = s_page_objects (page);
 
   while (iter != NULL) {
@@ -740,6 +742,4 @@ geda_net_object_modify (TOPLEVEL *toplevel, OBJECT *object,
 {
   object->line->x[whichone] = x;
   object->line->y[whichone] = y;
-
-  object->w_bounds_valid_for = NULL;
 }
