@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,13 +30,13 @@
  *  in the object struct.
  *  The subobjects are picture (st_picture), path (st_path), arcs (st_arc),
  *  a line (st_line), box (st_box), circle (st_circle), text (st_text) and
- *  a complex type (st_complex).
+ *  a component type (st_component).
  *
  *  Pins, nets and busses are just a kind of a line.
  *
- *  The complex object can carry many primary objects. If the complex
- *  object is a symbol, then the complex symbol contains all the pins,
- *  the text and the graphics.
+ *  The component object can carry many primary objects. If the
+ *  component object is a symbol, then the component symbol contains
+ *  all the pins, the text and the graphics.
  *
  *  \image html o_object_relations.png
  *  \image latex o_object_relations.pdf "object relations" width=14cm
@@ -196,9 +196,9 @@ OBJECT *o_object_copy (TOPLEVEL *toplevel,
       new_obj = geda_circle_object_copy (toplevel, selected);
       break;
 
-    case(OBJ_COMPLEX):
+    case(OBJ_COMPONENT):
     case(OBJ_PLACEHOLDER):
-      new_obj = o_complex_copy (toplevel, selected);
+      new_obj = o_component_copy (toplevel, selected);
       break;
 
     case(OBJ_TEXT):
@@ -293,20 +293,20 @@ s_delete_object(TOPLEVEL *toplevel, OBJECT *o_current)
     o_current->name = NULL;
 
 
-    /*	printf("sdeleting complex_basename\n");*/
-    g_free(o_current->complex_basename);
-    o_current->complex_basename = NULL;
+    /*	printf("sdeleting component_basename\n");*/
+    g_free(o_current->component_basename);
+    o_current->component_basename = NULL;
 
-    if (o_current->complex) {
+    if (o_current->component) {
 
-      if (o_current->complex->prim_objs) {
-        /* printf("sdeleting complex->primitive_objects\n");*/
-        geda_object_list_delete (toplevel, o_current->complex->prim_objs);
-        o_current->complex->prim_objs = NULL;
+      if (o_current->component->prim_objs) {
+        /* printf("sdeleting component's primitive objects\n");*/
+        geda_object_list_delete (toplevel, o_current->component->prim_objs);
+        o_current->component->prim_objs = NULL;
       }
 
-      g_free(o_current->complex);
-      o_current->complex = NULL;
+      g_free(o_current->component);
+      o_current->component = NULL;
     }
 
     o_attrib_detach_all (toplevel, o_current);
@@ -457,8 +457,6 @@ void o_set_line_options(TOPLEVEL *toplevel, OBJECT *o_current,
   o_current->line_length = length;
   o_current->line_space  = space;
 
-  /* Recalculate the object's bounding box */
-  o_current->w_bounds_valid_for = NULL;
   o_emit_change_notify (toplevel, o_current);
 
 }
@@ -625,7 +623,8 @@ geda_object_get_position (const GedaObject *object, gint *x, gint *y)
       case OBJ_PICTURE: func = geda_picture_object_get_position; break;
       case OBJ_CIRCLE:  func = geda_circle_object_get_position;  break;
       case OBJ_PLACEHOLDER:
-      case OBJ_COMPLEX: func = geda_complex_object_get_position; break;
+      case OBJ_COMPONENT:
+                        func = geda_component_object_get_position; break;
       case OBJ_TEXT:    func = geda_text_object_get_position;    break;
       case OBJ_PATH:    func = geda_path_object_get_position;    break;
       case OBJ_PIN:     func = geda_pin_object_get_position;     break;
@@ -664,7 +663,8 @@ geda_object_translate (GedaObject *object, gint dx, gint dy)
       case OBJ_PICTURE: func = geda_picture_object_translate; break;
       case OBJ_CIRCLE:  func = geda_circle_object_translate;  break;
       case OBJ_PLACEHOLDER:
-      case OBJ_COMPLEX: func = geda_complex_object_translate; break;
+      case OBJ_COMPONENT:
+                        func = geda_component_object_translate; break;
       case OBJ_TEXT:    func = geda_text_object_translate;    break;
       case OBJ_PATH:    func = geda_path_object_translate;    break;
       case OBJ_PIN:     func = geda_pin_object_translate;     break;
@@ -703,7 +703,8 @@ void geda_object_rotate (TOPLEVEL *toplevel, int world_centerx, int world_center
       case OBJ_PICTURE: func = geda_picture_object_rotate; break;
       case OBJ_CIRCLE:  func = geda_circle_object_rotate;  break;
       case OBJ_PLACEHOLDER:
-      case OBJ_COMPLEX: func = geda_complex_object_rotate; break;
+      case OBJ_COMPONENT:
+                        func = geda_component_object_rotate; break;
       case OBJ_TEXT:    func = geda_text_object_rotate;    break;
       case OBJ_PATH:    func = geda_path_object_rotate;    break;
       case OBJ_PIN:     func = geda_pin_object_rotate;     break;
@@ -741,7 +742,8 @@ void geda_object_mirror (TOPLEVEL *toplevel, int world_centerx, int world_center
       case OBJ_PICTURE: func = geda_picture_object_mirror; break;
       case OBJ_CIRCLE:  func = geda_circle_object_mirror;  break;
       case OBJ_PLACEHOLDER:
-      case OBJ_COMPLEX: func = geda_complex_object_mirror; break;
+      case OBJ_COMPONENT:
+                        func = geda_component_object_mirror; break;
       case OBJ_TEXT:    func = geda_text_object_mirror;    break;
       case OBJ_PATH:    func = geda_path_object_mirror;    break;
       case OBJ_PIN:     func = geda_pin_object_mirror;     break;
@@ -806,7 +808,7 @@ geda_object_shortest_distance_full (TOPLEVEL *toplevel, OBJECT *object,
     case OBJ_PICTURE:     func = geda_picture_object_shortest_distance;  break;
     case OBJ_CIRCLE:      func = geda_circle_object_shortest_distance;   break;
     case OBJ_PLACEHOLDER:
-    case OBJ_COMPLEX:     func = geda_complex_object_shortest_distance;  break;
+    case OBJ_COMPONENT:   func = geda_component_object_shortest_distance;  break;
     case OBJ_TEXT:        func = geda_text_object_shortest_distance;     break;
     case OBJ_PATH:        func = geda_path_object_shortest_distance;     break;
     case OBJ_ARC:         func = geda_arc_object_shortest_distance;      break;
@@ -822,28 +824,6 @@ geda_object_shortest_distance_full (TOPLEVEL *toplevel, OBJECT *object,
   return shortest_distance;
 }
 
-/*! \brief Mark an OBJECT's cached bounds as invalid
- *  \par Function Description
- *  Recursively marks the cached bounds of the given OBJECT and its
- *  parents as having been invalidated and in need of an update. They
- *  will be recalculated next time the OBJECT's bounds are requested
- *  (e.g. via geda_object_calculate_visible_bounds() ).
- *  \param [in] toplevel
- *  \param [in] object
- *
- *  \todo Turn this into a macro?
- */
-void
-o_bounds_invalidate (TOPLEVEL *toplevel, GedaObject *object)
-{
-  GedaObject *iter = object;
-
-  while (iter != NULL) {
-    iter->w_bounds_valid_for = NULL;
-    iter = iter->parent;
-  }
-}
-
 
 /*! \brief Change the color of an object
  *
@@ -860,9 +840,9 @@ void o_set_color (TOPLEVEL *toplevel, OBJECT *object, int color)
 
   object->color = color;
 
-  if (object->type == OBJ_COMPLEX ||
+  if (object->type == OBJ_COMPONENT ||
       object->type == OBJ_PLACEHOLDER)
-    geda_object_list_set_color (object->complex->prim_objs, color, toplevel);
+    geda_object_list_set_color (object->component->prim_objs, color, toplevel);
 }
 
 
@@ -873,30 +853,29 @@ void o_set_color (TOPLEVEL *toplevel, OBJECT *object, int color)
  * not currently associated with a PAGE, returns NULL. If \a object is
  * part of a compound object, recurses upward.
  *
- * \param [in] toplevel  The TOPLEVEL structure.
  * \param [in] object    The OBJECT for which to retrieve the parent PAGE.
  * \return The PAGE which owns \a object or NULL.
  *
  * \sa s_page_append_object() s_page_append() s_page_remove()
  */
 PAGE *
-o_get_page (TOPLEVEL *toplevel, OBJECT *object)
+o_get_page (OBJECT *object)
 {
   if (object->parent != NULL) {
-    return o_get_page (toplevel, object->parent);
+    return o_get_page (object->parent);
   }
   return object->page;
 }
 
-/*! \brief Get an object's containing complex object.
+/*! \brief Get an object's containing component object.
  *
  * \par Function Description
- * If \a object is part of a complex #OBJECT, returns that
+ * If \a object is part of a component #OBJECT, returns that
  * #OBJECT. Otherwise, returns NULL.
  *
  * \param [in] toplevel  The TOPLEVEL structure.
  * \param [in] object    The OBJECT for which to get the containing OBJECT.
- * \return The complex OBJECT which owns \a object, or NULL.
+ * \return The component OBJECT which owns \a object, or NULL.
  */
 OBJECT *
 o_get_parent (TOPLEVEL *toplevel, OBJECT *object)
@@ -996,6 +975,11 @@ void
 o_emit_pre_change_notify (TOPLEVEL *toplevel, OBJECT *object)
 {
   GList *iter;
+
+  if (toplevel == NULL) {
+    return;
+  }
+
   for (iter = toplevel->change_notify_funcs;
        iter != NULL; iter = g_list_next (iter)) {
 
@@ -1022,6 +1006,11 @@ void
 o_emit_change_notify (TOPLEVEL *toplevel, OBJECT *object)
 {
   GList *iter;
+
+  if (toplevel == NULL) {
+    return;
+  }
+
   for (iter = toplevel->change_notify_funcs;
        iter != NULL; iter = g_list_next (iter)) {
 
@@ -1075,10 +1064,7 @@ void
 o_set_visibility (TOPLEVEL *toplevel, OBJECT *object, int visibility)
 {
   g_return_if_fail (object != NULL);
-  if (object->visibility != visibility) {
-    object->visibility = visibility;
-    o_bounds_invalidate (toplevel, object);
-  }
+  object->visibility = visibility;
 }
 
 /*! \brief Return the bounds of the given object.
@@ -1112,105 +1098,102 @@ geda_object_calculate_visible_bounds (TOPLEVEL *toplevel,
     return 0;
   }
 
-  if (o_current->w_bounds_valid_for != toplevel) {
-    GedaBounds bounds;
+  GedaBounds bounds;
 
-    switch(o_current->type) {
+  switch(o_current->type) {
 
-      case(OBJ_LINE):
-        if (o_current->line == NULL) {
-          return 0;
-        }
-        geda_line_object_calculate_bounds (toplevel, o_current, &bounds);
-        break;
-
-      case(OBJ_NET):
-        if (o_current->line == NULL) {
-          return 0;
-        }
-        geda_net_object_calculate_bounds (toplevel, o_current, &bounds);
-        break;
-
-      case(OBJ_BUS):
-        if (o_current->line == NULL) {
-          return 0;
-        }
-        geda_bus_object_calculate_bounds(toplevel, o_current, &bounds);
-        break;
-
-      case(OBJ_BOX):
-        if (o_current->box == NULL) {
-          return 0;
-        }
-        geda_box_object_calculate_bounds (toplevel, o_current, &bounds);
-        break;
-
-      case(OBJ_PATH):
-        g_return_val_if_fail (o_current->path != NULL, 0);
-        if (o_current->path->num_sections <= 0) {
-          return 0;
-        }
-        geda_path_object_calculate_bounds (toplevel, o_current, &bounds);
-        break;
-
-      case(OBJ_PICTURE):
-        if (o_current->picture == NULL) {
-          return 0;
-        }
-        geda_picture_object_calculate_bounds (o_current, &bounds);
-        break;
-
-      case(OBJ_CIRCLE):
-        if (o_current->circle == NULL) {
-          return 0;
-        }
-        geda_circle_object_calculate_bounds (toplevel, o_current, &bounds);
-        break;
-
-      case(OBJ_COMPLEX):
-      case(OBJ_PLACEHOLDER):
-        /* realc routine Add this somewhere */
-        /* libhack */
-        /* o_recalc(toplevel, o_current->complex);*/
-
-        if (o_current->complex->prim_objs == NULL)
-          return 0;
-
-        geda_complex_object_calculate_bounds(toplevel, o_current, &bounds);
-        break;
-
-      case(OBJ_PIN):
-        if (o_current->line == NULL) {
-          return 0;
-        }
-        geda_pin_object_calculate_bounds (toplevel, o_current, &bounds);
-        break;
-
-      case(OBJ_ARC):
-        if (o_current->arc == NULL) {
-          return 0;
-        }
-        geda_arc_object_calculate_bounds (toplevel, o_current,
-                                          &bounds.min_x,
-                                          &bounds.min_y,
-                                          &bounds.max_x,
-                                          &bounds.max_y);
-        break;
-
-      case(OBJ_TEXT):
-        if (!geda_text_object_calculate_bounds(toplevel, o_current, &bounds)) {
-          return 0;
-        }
-        break;
-
-      default:
-        return 0;
+  case(OBJ_LINE):
+    if (o_current->line == NULL) {
+      return 0;
     }
+    geda_line_object_calculate_bounds (toplevel, o_current, &bounds);
+    break;
 
-    o_current->bounds = bounds;
-    o_current->w_bounds_valid_for = toplevel;
+  case(OBJ_NET):
+    if (o_current->line == NULL) {
+      return 0;
+    }
+    geda_net_object_calculate_bounds (toplevel, o_current, &bounds);
+    break;
+
+  case(OBJ_BUS):
+    if (o_current->line == NULL) {
+      return 0;
+    }
+    geda_bus_object_calculate_bounds(toplevel, o_current, &bounds);
+    break;
+
+  case(OBJ_BOX):
+    if (o_current->box == NULL) {
+      return 0;
+    }
+    geda_box_object_calculate_bounds (toplevel, o_current, &bounds);
+    break;
+
+  case(OBJ_PATH):
+    g_return_val_if_fail (o_current->path != NULL, 0);
+    if (o_current->path->num_sections <= 0) {
+      return 0;
+    }
+    geda_path_object_calculate_bounds (toplevel, o_current, &bounds);
+    break;
+
+  case(OBJ_PICTURE):
+    if (o_current->picture == NULL) {
+      return 0;
+    }
+    geda_picture_object_calculate_bounds (o_current, &bounds);
+    break;
+
+  case(OBJ_CIRCLE):
+    if (o_current->circle == NULL) {
+      return 0;
+    }
+    geda_circle_object_calculate_bounds (toplevel, o_current, &bounds);
+    break;
+
+  case(OBJ_COMPONENT):
+  case(OBJ_PLACEHOLDER):
+    /* realc routine Add this somewhere */
+    /* libhack */
+    /* o_recalc(toplevel, o_current->component);*/
+
+    if (o_current->component->prim_objs == NULL)
+      return 0;
+
+    geda_component_object_calculate_bounds(toplevel, o_current, &bounds);
+    break;
+
+  case(OBJ_PIN):
+    if (o_current->line == NULL) {
+      return 0;
+    }
+    geda_pin_object_calculate_bounds (toplevel, o_current, &bounds);
+    break;
+
+  case(OBJ_ARC):
+    if (o_current->arc == NULL) {
+      return 0;
+    }
+    geda_arc_object_calculate_bounds (toplevel, o_current,
+                                      &bounds.min_x,
+                                      &bounds.min_y,
+                                      &bounds.max_x,
+                                      &bounds.max_y);
+    break;
+
+  case(OBJ_TEXT):
+    if (!geda_text_object_calculate_bounds(toplevel, o_current, &bounds)) {
+      return 0;
+    }
+    break;
+
+  default:
+    return 0;
   }
 
+  o_current->bounds = bounds;
+
   if (rleft != NULL) {
     *rleft = o_current->bounds.min_x;
   }
@@ -1254,7 +1237,6 @@ s_basic_init_object (OBJECT *new_node, int type, char const *name)
 
   /* Setup the bounding box */
   geda_bounds_init (&(new_node->bounds));
-  new_node->w_bounds_valid_for = NULL;
 
   /* Setup line/circle structs */
   new_node->line = NULL;
@@ -1264,11 +1246,11 @@ s_basic_init_object (OBJECT *new_node, int type, char const *name)
   new_node->box = NULL;
   new_node->picture = NULL;
   new_node->text = NULL;
-  new_node->complex = NULL;
+  new_node->component = NULL;
 
   new_node->conn_list = NULL;
 
-  new_node->complex_basename = NULL;
+  new_node->component_basename = NULL;
   new_node->parent = NULL;
 
   /* Setup the color */
