@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -146,7 +146,6 @@ PAGE *s_page_new (TOPLEVEL *toplevel, const gchar *filename)
   page->weak_refs = NULL;
 
   /* Backup variables */
-  g_get_current_time (&page->last_load_or_save_time);
   page->ops_since_last_backup = 0;
   page->saved_since_first_loaded = 0;
   page->do_autosave_backup = 0;
@@ -194,7 +193,8 @@ void s_page_delete (TOPLEVEL *toplevel, PAGE *page)
   real_filename = follow_symlinks (s_page_get_filename(page), NULL);
 
   if (real_filename == NULL) {
-    s_log_message (_("s_page_delete: Can't get the real filename of %1$s."),
+    s_log_message ("s_page_delete:");
+    s_log_message (_("Can't get the real filename of %1$s."),
                    s_page_get_filename (page));
   }
   else {
@@ -205,7 +205,8 @@ void s_page_delete (TOPLEVEL *toplevel, PAGE *page)
 	 (!g_file_test(backup_filename, G_FILE_TEST_IS_DIR)) )
     {
       if (unlink(backup_filename) != 0) {
-	s_log_message(_("s_page_delete: Unable to delete backup file %1$s."),
+        s_log_message ("s_page_delete:");
+	s_log_message (_("Unable to delete backup file %1$s."),
                       backup_filename);
       }
     }
