@@ -2,7 +2,7 @@
  * Copyright (C) 1998, 1999, 2000 Kazu Hirata / Ales Hvezda
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2017 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,8 +49,6 @@ TOPLEVEL *s_toplevel_new (void)
 
   toplevel->RC_list = NULL;
 
-  toplevel->bitmap_directory   = NULL;
-
   /* These values are the default extents of the schematic drawing area.
    *
    * The negative values allow symbols, residing at the origin, to be
@@ -68,22 +66,10 @@ TOPLEVEL *s_toplevel_new (void)
 
   toplevel->major_changed_refdes = NULL;
 
-  toplevel->net_consolidate = FALSE;
-
   /* The following is an attempt at getting (deterministic) defaults */
   /* for the following variables */
-  toplevel->attribute_promotion = FALSE;
-  toplevel->promote_invisible   = FALSE;
-  toplevel->keep_invisible      = FALSE;
-
-  toplevel->make_backup_files = TRUE;
-
-  toplevel->bus_ripper_symname = NULL;
-
   toplevel->force_boundingbox = FALSE;
 
-  toplevel->always_promote_attributes = NULL;
-
   toplevel->rendered_text_bounds_func = NULL;
   toplevel->rendered_text_bounds_data = NULL;
 
@@ -114,9 +100,6 @@ void s_toplevel_delete (TOPLEVEL *toplevel)
     g_source_remove (toplevel->auto_save_timeout);
   }
 
-  g_free (toplevel->bitmap_directory);
-  g_free (toplevel->bus_ripper_symname);
-
   /* delete all pages */
   s_page_delete_list (toplevel);
 
