@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -282,9 +282,9 @@ GList *o_read_attribs (TOPLEVEL *toplevel,
         object_list = g_list_prepend (object_list, new_obj);
         break;
 
-      case(OBJ_COMPLEX):
+      case(OBJ_COMPONENT):
       case(OBJ_PLACEHOLDER):
-        if ((new_obj = o_complex_read (toplevel, line, release_ver, fileformat_ver, err)) == NULL)
+        if ((new_obj = o_component_read (toplevel, line, release_ver, fileformat_ver, err)) == NULL)
           goto error;
         object_list = g_list_prepend (object_list, new_obj);
         break;
@@ -604,10 +604,10 @@ char *o_attrib_search_inherited_attribs_by_name (OBJECT *object,
                                                  const char *name,
                                                  int counter)
 {
-  g_return_val_if_fail (object->type == OBJ_COMPLEX ||
+  g_return_val_if_fail (object->type == OBJ_COMPONENT ||
                         object->type == OBJ_PLACEHOLDER, NULL);
 
-  return o_attrib_search_floating_attribs_by_name (object->complex->prim_objs, name, counter);
+  return o_attrib_search_floating_attribs_by_name (object->component->prim_objs, name, counter);
 }
 
 
@@ -650,7 +650,7 @@ char *o_attrib_search_object_attribs_by_name (OBJECT *object,
  *  This function aggregates the attached and inherited attributes
  *  belonging to a given OBJECT. (inherited attributes are those
  *  which live as toplevel un-attached attributes inside in a
- *  complex OBJECT's prim_objs).
+ *  component OBJECT's prim_objs).
  *
  *  \param [in] object       OBJECT whos attributes to return.
  *  \return A GList of attributes belinging to the passed object.
@@ -681,12 +681,12 @@ GList * o_attrib_return_attribs (OBJECT *object)
 
   attribs = g_list_reverse (attribs);
 
-  /* Inherited attributes (inside complex objects) */
-  if (object->type == OBJ_COMPLEX ||
+  /* Inherited attributes (inside component objects) */
+  if (object->type == OBJ_COMPONENT ||
       object->type == OBJ_PLACEHOLDER) {
 
     inherited_attribs =
-      o_attrib_find_floating_attribs (object->complex->prim_objs);
+      o_attrib_find_floating_attribs (object->component->prim_objs);
 
     attribs = g_list_concat (attribs, inherited_attribs);
   }
@@ -698,7 +698,7 @@ GList * o_attrib_return_attribs (OBJECT *object)
 /*! \brief Query whether a given attribute OBJECT is "inherited"
  *  \par Function Description
  *  This function returns TRUE if the given attribute OBJECT is a
- *  toplevel un-attached attribute inside a complex's prim_objs.
+ *  toplevel un-attached attribute inside a component's prim_objs.
  *
  *  \param [in] attrib       OBJECT who's status to query.
  *  \return TRUE if the given attribute is inside a symbol
