@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -315,7 +315,7 @@ s_hierarchy_traversepages (TOPLEVEL *toplevel, PAGE *p_current, gint flags)
     o_current = (OBJECT *)iter->data;
 
     /* only complex things like symbols can contain attributes */
-    if (o_current->type != OBJ_COMPLEX) continue;
+    if (o_current->type != OBJ_COMPONENT) continue;
 
     filename =
       o_attrib_search_attached_attribs_by_name (o_current, "source", 0);
