@@ -1,6 +1,6 @@
 /* Lepton EDA library - Scheme API
  * Copyright (C) 2011-2012 Peter Brett <peter@peter-b.co.uk>
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -126,7 +126,7 @@ error_from_gerror (const gchar *subr, GError **error)
  * \see eda_config_get_default_context().
  *
  * \note Scheme API: Implements the \%default-config-context procedure
- * in the (geda core config) module.
+ * in the (lepton core config) module.
  *
  * \return an #EdaConfig smob for the default context.
  */
@@ -143,7 +143,7 @@ SCM_DEFINE (default_config_context, "%default-config-context", 0, 0, 0,
  * \see eda_config_get_system_context().
  *
  * \note Scheme API: Implements the \%system-config-context procedure
- * in the (geda core config) module.
+ * in the (lepton core config) module.
  *
  * \return an #EdaConfig smob for the system context.
  */
@@ -160,7 +160,7 @@ SCM_DEFINE (system_config_context, "%system-config-context", 0, 0, 0,
  * \see eda_config_get_user_context().
  *
  * \note Scheme API: Implements the \%user-config-context procedure
- * in the (geda core config) module.
+ * in the (lepton core config) module.
  *
  * \return an #EdaConfig smob for the user context.
  */
@@ -178,7 +178,7 @@ SCM_DEFINE (user_config_context, "%user-config-context", 0, 0, 0,
  * \see eda_config_get_context_for_path().
  *
  * \note Scheme API: Implements the \%path-config-context procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param [in] path_s Path to get context for, as a string.
  * \return an #EdaConfig smob for \a path.
@@ -204,6 +204,23 @@ SCM_DEFINE (path_config_context, "%path-config-context", 1, 0, 0,
   return result;
 }
 
+/*! \brief Get the cache configuration context.
+ * \par Function Description
+ * Returns the configuration context for program-specific settings.
+ *
+ * \see eda_config_get_cache_context().
+ *
+ * \note Scheme API: Implements the \%cache-config-context procedure
+ * in the (lepton core config) module.
+ *
+ * \return an #EdaConfig smob for the cache context.
+ */
+SCM_DEFINE (cache_config_context, "%cache-config-context", 0, 0, 0,
+            (), "Get cache configuration context.")
+{
+  return edascm_from_config (eda_config_get_cache_context());
+}
+
 /*! \brief Get a configuration context's filename.
  * \par Function Description
  * Returns the underlying filename for the configuration context \a
@@ -212,7 +229,7 @@ SCM_DEFINE (path_config_context, "%path-config-context", 1, 0, 0,
  * \see eda_config_get_file().
  *
  * \note Scheme API: Implements the \%config-filename procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s  #EdaConfig smob for configuration context.
  * \return string containing configuration filename.
@@ -245,27 +262,34 @@ SCM_DEFINE (config_filename, "%config-filename", 1, 0, 0,
  * \see eda_config_load().
  *
  * \note Scheme API: Implements the \%config-load! procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
- * \param cfg_s  #EdaConfig smob for configuration context to load.
+ * \param cfg_s    #EdaConfig smob for configuration context to load.
+ * \param force_s  Force configuration loading even if it has been already loaded.
  * \return \a cfg_s.
  */
-SCM_DEFINE (config_load_x, "%config-load!", 1, 0, 0,
-            (SCM cfg_s), "Load configuration parameters from file.")
+SCM_DEFINE (config_load_x, "%config-load!", 2, 0, 0,
+            (SCM cfg_s, SCM force_s), "Load configuration parameters from file.")
 {
   SCM_ASSERT (EDASCM_CONFIGP (cfg_s), cfg_s, SCM_ARG1,
               s_config_load_x);
+  SCM_ASSERT (scm_is_bool (force_s), force_s, SCM_ARG2,
+              s_config_load_x);
 
   EdaConfig *cfg = edascm_to_config (cfg_s);
+  gboolean force_load = scm_to_bool (force_s);
   GError *error = NULL;
 
-  if (!eda_config_load (cfg, &error))
+  if (!eda_config_is_loaded (cfg) || force_load)
   {
-    /* Missing configuration file is not an error:
-    */
-    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
+    if (!eda_config_load (cfg, &error))
     {
-      error_from_gerror (s_config_load_x, &error);
+      /* Missing configuration file is not an error:
+      */
+      if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
+      {
+        error_from_gerror (s_config_load_x, &error);
+      }
     }
   }
 
@@ -280,7 +304,7 @@ SCM_DEFINE (config_load_x, "%config-load!", 1, 0, 0,
  * \see eda_config_is_loaded().
  *
  * \note Scheme API: Implements the \%config-loaded? procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s  #EdaConfig smob of configuration context.
  * \return #t if \a cfg_s has been loaded; #f otherwise.
@@ -303,7 +327,7 @@ SCM_DEFINE (config_loaded_p, "%config-loaded?", 1, 0, 0,
  * \see eda_config_save().
  *
  * \note Scheme API: Implements the \%config-save! procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s #EdaConfig smob of configuration context.
  * \return \a cfg_s.
@@ -331,7 +355,7 @@ SCM_DEFINE (config_save_x, "%config-save!", 1, 0, 0,
  * \see eda_config_is_changed().
  *
  * \note Scheme API: Implements the \%config-changed? procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s #EdaConfig smob of configuration context.
  * \return #t if \a cfg_s has unsaved changes, #f otherwise.
@@ -355,7 +379,7 @@ SCM_DEFINE (config_changed_p, "%config-changed?", 1, 0, 0,
  * \see eda_config_get_parent().
  *
  * \note Scheme API: Implements the \%config-parent procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s #EdaConfig smob of configuration context.
  * \return parent context of \a cfg_s, or #f.
@@ -380,7 +404,7 @@ SCM_DEFINE (config_parent, "%config-parent", 1, 0, 0,
  * \see eda_config_set_parent().
  *
  * \note Scheme API: Implements the \%set-config-parent! procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param cfg_s #EdaConfig smob of configuration context.
  * \param parent_s #EdaConfig smob of new parent context, or #f.
@@ -409,7 +433,7 @@ SCM_DEFINE (set_config_parent_x, "%set-config-parent!", 2, 0, 0,
  * \see eda_config_is_trusted().
  *
  * \note Scheme API: Implements the \%config-trusted? procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param cfg_s #EdaConfig smob of configuration context.
  * \return #t if \a cfg_s is trusted, #f otherwise.
@@ -431,7 +455,7 @@ SCM_DEFINE (config_trusted_p, "%config-trusted?", 1, 0, 0,
  * \see eda_config_set_trusted().
  *
  * \note Scheme API: Implements the \%set-config-trusted! procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param cfg_s #EdaConfig smob of configuration context.
  * \param trusted_s #f if \a cfg_s is not to be trusted.
@@ -457,7 +481,7 @@ SCM_DEFINE (set_config_trusted_x, "%set-config-trusted!", 2, 0, 0,
  * \see eda_config_get_groups().
  *
  * \note Scheme API: Implements the \%config-groups procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param cfg_s #EdaConfig smob of configuration context.
  * \return a list of available group names as strings.
@@ -495,7 +519,7 @@ SCM_DEFINE (config_groups, "%config-groups", 1, 0, 0,
  * \see eda_config_has_group().
  *
  * \note Scheme API: Implements the \%config-has-group? procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param cfg_s #EdaConfig smob of configuration context.
  * \param group_s Group name as a string.
@@ -527,7 +551,7 @@ SCM_DEFINE (config_has_group_p, "%config-has-group?", 2, 0, 0,
  * \see eda_config_get_keys().
  *
  * \note Scheme API: Implements the \%config-keys procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param cfg_s #EdaConfig smob of configuration context.
  * \param group_s Group name as a string.
@@ -575,7 +599,7 @@ SCM_DEFINE (config_keys, "%config-keys", 2, 0, 0,
  * \see eda_config_get_source().
  *
  * \note Scheme API: Implements the \%config-source procedure in the
- * (geda core config module).
+ * (lepton core config module).
  *
  * \param cfg_s #EdaConfig smob of configuration context.
  * \param group_s Group name as a string.
@@ -610,7 +634,7 @@ SCM_DEFINE (config_source, "%config-source", 3, 0, 0,
  * \see eda_config_get_string().
  *
  * \note Scheme API: Implements the \%config-string procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -648,7 +672,7 @@ SCM_DEFINE (config_string, "%config-string", 3, 0, 0,
  * \see eda_config_get_boolean().
  *
  * \note Scheme API: Implements the \%config-boolean procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -683,7 +707,7 @@ SCM_DEFINE (config_boolean, "%config-boolean", 3, 0, 0,
  * \see eda_config_get_int().
  *
  * \note Scheme API: Implements the \%config-int procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -718,7 +742,7 @@ SCM_DEFINE (config_int, "%config-int", 3, 0, 0,
  * \see eda_config_get_double().
  *
  * \note Scheme API: Implements the \%config-real procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -753,7 +777,7 @@ SCM_DEFINE (config_real, "%config-real", 3, 0, 0,
  * \see eda_config_get_string_list().
  *
  * \note Scheme API: Implements the \%config-string-list procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -796,7 +820,7 @@ SCM_DEFINE (config_string_list, "%config-string-list", 3, 0, 0,
  * \see eda_config_get_boolean_list().
  *
  * \note Scheme API: Implements the \%config-boolean-list procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -839,7 +863,7 @@ SCM_DEFINE (config_boolean_list, "%config-boolean-list", 3, 0, 0,
  * \see eda_config_get_int_list().
  *
  * \note Scheme API: Implements the \%config-int-list procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -882,7 +906,7 @@ SCM_DEFINE (config_int_list, "%config-int-list", 3, 0, 0,
  * \see eda_config_get_double_list().
  *
  * \note Scheme API: Implements the \%config-real-list procedure in
- * the (geda core config) module.
+ * the (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -925,7 +949,7 @@ SCM_DEFINE (config_real_list, "%config-real-list", 3, 0, 0,
  * integers, real numbers or booleans.
  *
  * \note Scheme API: Implements the \%set-config! procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -1055,7 +1079,7 @@ edascm_config_event_dispatcher (EdaConfig *cfg, const char *group,
  * caught and logged.
  *
  * \note Scheme API: Implements the \%add-config-event! procedure in the
- * (geda core config) module.
+ * (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param proc_s   Procedure to add as configuration change handler.
@@ -1100,7 +1124,7 @@ SCM_DEFINE (add_config_event_x, "%add-config-event!", 2, 0, 0,
  * the context \a cfg.
  *
  * \note Scheme API: Implements the \%remove-config-event! procedure
- * in the (geda core config) module.
+ * in the (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param proc_s   Procedure to remove as configuration change handler.
@@ -1144,7 +1168,7 @@ SCM_DEFINE (remove_config_event_x, "%remove-config-event!", 2, 0, 0,
  * \see eda_config_remove_key().
  *
  * \note Scheme API: Implements the \%config-remove-key!
- * procedure in the (geda core config) module.
+ * procedure in the (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -1191,7 +1215,7 @@ SCM_DEFINE (config_remove_key, "%config-remove-key!", 3, 0, 0,
  * \see eda_config_remove_group().
  *
  * \note Scheme API: Implements the \%config-remove-group!
- * procedure in the (geda core config) module.
+ * procedure in the (lepton core config) module.
  *
  * \param cfg_s    #EdaConfig smob of configuration context.
  * \param group_s  Group name as a string.
@@ -1236,11 +1260,11 @@ SCM_DEFINE (config_remove_group, "%config-remove-group!", 2, 0, 0,
  * \see config_set_legacy_mode().
  *
  * \note Scheme API: Implements the \%config-set-legacy-mode!
- * procedure in the (geda core config) module.
+ * procedure in the (lepton core config) module.
  *
  * \param legacy_s  Boolean: set legacy mode or not.
  *
- * \return         SCM_BOOL_T.
+ * \return  Previously set config mode: SCM_BOOL_T - legacy, SCM_BOOL_F otherwise.
  */
 SCM_DEFINE (config_set_legacy_mode_x, "%config-set-legacy-mode!", 1, 0, 0,
             (SCM  legacy_s),
@@ -1248,21 +1272,47 @@ SCM_DEFINE (config_set_legacy_mode_x, "%config-set-legacy-mode!", 1, 0, 0,
 {
   SCM_ASSERT (scm_is_bool (legacy_s), legacy_s, SCM_ARG1, s_config_set_legacy_mode_x);
 
+  gboolean result = config_get_legacy_mode();
+
   config_set_legacy_mode (scm_to_bool (legacy_s));
 
-  return SCM_BOOL_T;
+  return result ? SCM_BOOL_T : SCM_BOOL_F;
+}
+
+
+
+/*! \brief Test whether legacy configuration mode is currently in use.
+ *
+ * \par Function Description
+ * This function is added to assist in config migration and
+ * not intended for the end user.
+ * It will be removed.
+ *
+ * \see config_get_legacy_mode().
+ *
+ * \note Scheme API: Implements the \%config-legacy-mode?
+ * procedure in the (lepton core config) module.
+ *
+ * \return  SCM_BOOL_T or SCM_BOOL_F.
+ */
+SCM_DEFINE (config_legacy_mode_p, "%config-legacy-mode?", 0, 0, 0,
+            (), "Whether legacy configuration mode is used.")
+{
+  gboolean result = config_get_legacy_mode();
+
+  return result ? SCM_BOOL_T : SCM_BOOL_F;
 }
 
 
 
 /*!
- * \brief Create the (geda core config) Scheme module.
+ * \brief Create the (lepton core config) Scheme module.
  * \par Function Description
- * Defines procedures in the (geda core config) module. The module can
- * be accessed using (use-modules (geda core config)).
+ * Defines procedures in the (lepton core config) module. The module can
+ * be accessed using (use-modules (lepton core config)).
  */
 static void
-init_module_geda_core_config (void *unused)
+init_module_lepton_core_config (void *unused)
 {
   /* Register the functions and symbols */
   #include "scheme_config.x"
@@ -1272,6 +1322,7 @@ init_module_geda_core_config (void *unused)
                 s_system_config_context,
                 s_user_config_context,
                 s_path_config_context,
+                s_cache_config_context,
                 s_config_filename,
                 s_config_load_x,
                 s_config_loaded_p,
@@ -1299,11 +1350,12 @@ init_module_geda_core_config (void *unused)
                 s_config_remove_key,
                 s_config_remove_group,
                 s_config_set_legacy_mode_x,
+                s_config_legacy_mode_p,
                 NULL);
 }
 
 /*!
- * \brief Initialise the basic gEDA configuration manipulation procedures.
+ * \brief Initialise the basic Lepton EDA configuration manipulation procedures.
  * \par Function Description
  * Registers some Scheme procedures for working with #EdaConfig
  * smobs. Should only be called by edascm_init().
@@ -1311,8 +1363,8 @@ init_module_geda_core_config (void *unused)
 void
 edascm_init_config ()
 {
-  /* Define the (geda core object) module */
-  scm_c_define_module ("geda core config",
-                       (void (*)(void*)) init_module_geda_core_config,
+  /* Define the (lepton core config) module */
+  scm_c_define_module ("lepton core config",
+                       (void (*)(void*)) init_module_lepton_core_config,
                        NULL);
 }
