@@ -1,7 +1,7 @@
 /* Lepton EDA library - Scheme API
  * Copyright (C) 2010-2013 Peter Brett <peter@peter-b.co.uk>
  * Copyright (C) 2010-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,11 +41,12 @@ edascm_init_impl (void *data)
 {
   #include "scheme_init.x"
 
-  scm_setlocale(scm_variable_ref(scm_c_lookup("LC_ALL")), scm_from_locale_string(""));
+  scm_setlocale (scm_variable_ref (scm_c_lookup ("LC_ALL")),
+                 SCM_UNDEFINED);
   edascm_init_smob ();
   edascm_init_toplevel ();
   edascm_init_object ();
-  edascm_init_complex ();
+  edascm_init_component ();
   edascm_init_page ();
   edascm_init_attrib ();
   edascm_init_os ();
