@@ -1,7 +1,7 @@
 /* Lepton EDA library - Scheme API
  * Copyright (C) 2010-2012 Peter Brett <peter@peter-b.co.uk>
  * Copyright (C) 2011-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,9 +74,9 @@ SCM_SYMBOL (lineto_sym , "lineto");
 SCM_SYMBOL (curveto_sym , "curveto");
 SCM_SYMBOL (closepath_sym , "closepath");
 
-void o_page_changed (TOPLEVEL *t, OBJECT *o)
+void o_page_changed (OBJECT *o)
 {
-  PAGE *p = o_get_page (t, o);
+  PAGE *p = o_get_page (o);
   if (p != NULL) p->CHANGED = TRUE;
 }
 
@@ -175,7 +175,7 @@ edascm_is_object_type (SCM smob, int type)
  * smob.
  *
  * \note Scheme API: Implements the %copy-object procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param [in] obj_s an #OBJECT smob.
  * \return a new #OBJECT smob containing a copy of the #OBJECT in \a obj_s.
@@ -204,7 +204,7 @@ SCM_DEFINE (copy_object, "%copy-object", 1, 0, 0,
  * Returns a symbol describing the type of the #OBJECT smob \a obj_s.
  *
  * \note Scheme API: Implements the %object-type procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param [in] obj_s an #OBJECT smob.
  * \return a Scheme symbol representing the object type.
@@ -226,7 +226,8 @@ SCM_DEFINE (object_type, "%object-type", 1, 0, 0,
   case OBJ_PICTURE: result = picture_sym;    break;
   case OBJ_CIRCLE:  result = circle_sym;     break;
   case OBJ_PLACEHOLDER:
-  case OBJ_COMPLEX: result = complex_sym;    break;
+  case OBJ_COMPONENT:
+                    result = complex_sym;    break;
   case OBJ_TEXT:    result = text_sym;       break;
   case OBJ_PATH:    result = path_sym;       break;
   case OBJ_PIN:     result = pin_sym;        break;
@@ -245,7 +246,7 @@ SCM_DEFINE (object_type, "%object-type", 1, 0, 0,
  * Returns an internal id number of the #OBJECT smob \a obj_s.
  *
  * \note Scheme API: Implements the %object-id procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param [in] obj_s an #OBJECT smob.
  * \return a Scheme symbol representing the object type.
@@ -279,7 +280,7 @@ SCM_DEFINE (object_id, "%object-id", 1, 0, 0,
  * objects, not the visible bounds.
  *
  * \note Scheme API: Implements the %object-bounds procedure in the
- * (geda core object) module.  The procedure takes any number of
+ * (lepton core object) module.  The procedure takes any number of
  * #OBJECT smobs as arguments.
  *
  * \param [in] rst_s Variable-length list of #OBJECT arguments.
@@ -297,23 +298,12 @@ SCM_DEFINE (object_bounds, "%object-bounds", 0, 0, 1,
     success = world_get_object_glist_bounds (toplevel, obj_list,
                                              &left, &top, &right, &bottom);
   } else {
-    GList *list;
     toplevel->show_hidden_text = TRUE;
 
-    for (list = obj_list; list != NULL; list = g_list_next(list)) {
-      OBJECT *o_current = (OBJECT *) list->data;
-      o_current->w_bounds_valid_for = NULL;
-    }
-
     success = world_get_object_glist_bounds (toplevel, obj_list,
                                              &left, &top, &right, &bottom);
 
     toplevel->show_hidden_text = FALSE;
-
-    for (list = obj_list; list != NULL; list = g_list_next(list)) {
-      OBJECT *o_current = (OBJECT *) list->data;
-      o_current->w_bounds_valid_for = NULL;
-    }
   }
 
   SCM result = SCM_BOOL_F;
@@ -344,7 +334,7 @@ SCM_DEFINE (object_bounds, "%object-bounds", 0, 0, 1,
  *    -# For other styles, dot/dash spacing and dash length.
  *
  * \note Scheme API: Implements the %object-stroke procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s object to get stroke settings for.
  * \return a list of stroke parameters.
@@ -413,7 +403,7 @@ SCM_DEFINE (object_stroke, "%object-stroke", 1, 0, 0,
  * SCM_UNDEFINED if not required by the dash style \a dash_s.
  *
  * \note Scheme API: Implements the %object-stroke procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s object to set stroke settings for.
  * \param width_s new stroke width for \a obj_s.
@@ -500,7 +490,7 @@ SCM_DEFINE (set_object_stroke_x, "%set-object-stroke!", 4, 2, 0,
                       width,
                       length,
                       space);
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return obj_s;
 }
@@ -519,7 +509,7 @@ SCM_DEFINE (set_object_stroke_x, "%set-object-stroke!", 4, 2, 0,
  *      spacing for mesh fills.
  *
  * \note Scheme API: Implements the %object-fill procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s object to get fill settings for.
  * \return a list of fill parameters.
@@ -576,7 +566,7 @@ SCM_DEFINE (object_fill, "%object-fill", 1, 0, 0,
  * space2_s
  *
  * \note Scheme API: Implements the %object-fill procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s object to set fill settings for.
  * \return \a obj_s.
@@ -663,7 +653,7 @@ SCM_DEFINE (set_object_fill_x, "%set-object-fill!", 2, 5, 0,
                       angle1,
                       space2,
                       angle2);
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return obj_s;
 }
@@ -675,7 +665,7 @@ SCM_DEFINE (set_object_fill_x, "%set-object-fill!", 2, 5, 0,
  * object types.
  *
  * \note Scheme API: Implements the %object-color procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param [in] obj_s #OBJECT smob to inspect.
  * \return The colormap index used by \a obj_s.
@@ -697,7 +687,7 @@ SCM_DEFINE (object_color, "%object-color", 1, 0, 0,
  * for some object types.
  *
  * \note Scheme API: Implements the %set-object-color! procedure in
- * the (geda core object) module.
+ * the (lepton core object) module.
  *
  * \param obj_s   #OBJECT smob to modify.
  * \param color_s new colormap index to use for \a obj_s.
@@ -715,7 +705,7 @@ SCM_DEFINE (set_object_color_x, "%set-object-color!", 2, 0, 0,
   OBJECT *obj = edascm_to_object (obj_s);
   o_set_color (toplevel, obj, scm_to_int (color_s));
 
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return obj_s;
 }
@@ -729,7 +719,7 @@ SCM_DEFINE (set_object_color_x, "%set-object-color!", 2, 0, 0,
  * object is considered to be unlocked, otherwise it is locked.
  *
  * \note Scheme API: Implements the %object-selectable? procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s  #OBJECT smob to inspect.
  *
@@ -745,7 +735,7 @@ SCM_DEFINE (object_selectable_p, "%object-selectable?", 1, 0, 0,
 
   return scm_from_bool (obj->selectable);
 
-} /* object_selectable_x() */
+} /* object_selectable_p() */
 
 
 
@@ -755,7 +745,7 @@ SCM_DEFINE (object_selectable_p, "%object-selectable?", 1, 0, 0,
  * Set object's selectable flag: locked objects cannot be selected.
  *
  * \note Scheme API: Implements the %set-object-selectable! procedure in
- * the (geda core object) module.
+ * the (lepton core object) module.
  *
  * \param obj_s         #OBJECT smob to modify.
  * \param selectable_s  boolean: object's selectable flag.
@@ -780,8 +770,7 @@ SCM_DEFINE (set_object_selectable_x, "%set-object-selectable!", 2, 0, 0,
 
     /* mark the page as changed:
     */
-    TOPLEVEL* toplevel = edascm_c_current_toplevel();
-    o_page_changed (toplevel, obj);
+    o_page_changed (obj);
   }
 
   return obj_s;
@@ -790,13 +779,102 @@ SCM_DEFINE (set_object_selectable_x, "%set-object-selectable!", 2, 0, 0,
 
 
 
+/*! \brief Check whether an object is embedded.
+ *
+ * \note Scheme API: Implements the %object-embedded? procedure in the
+ * (lepton core object) module.
+ *
+ * \param obj_s  #OBJECT smob to inspect.
+ *
+ * \return       Boolean value indicating whether \a obj_s is embedded.
+ */
+SCM_DEFINE (object_embedded_p, "%object-embedded?", 1, 0, 0,
+            (SCM obj_s), "Check whether an object is embedded.")
+{
+  SCM_ASSERT (EDASCM_OBJECTP (obj_s), obj_s,
+              SCM_ARG1, s_object_embedded_p);
+
+  OBJECT*  obj = edascm_to_object (obj_s);
+  gboolean ret = FALSE;
+
+  if (obj->type == OBJ_COMPONENT)
+  {
+    ret = o_component_is_embedded (obj);
+  }
+  else
+  if (obj->type == OBJ_PICTURE)
+  {
+    ret = o_picture_is_embedded (obj);
+  }
+
+  return scm_from_bool (ret);
+
+} /* object_embedded_p() */
+
+
+
+/*! \brief Embed or unembed an object.
+ *
+ * \par Function Description
+ * Embeds (or unembeds) component or picture.
+ * If either the object \a obj_s is already embedded and \a embed_s is #t,
+ * or \a obj_s is not embedded and \a embed_s is #f,
+ * or \a obj_s is not a component or picture, does nothing.
+ *
+ * \note Scheme API: Implements the %set-object-embedded! procedure in
+ * the (lepton core object) module.
+ *
+ * \param obj_s    #OBJECT smob to modify.
+ * \param embed_s  boolean: whether to embed (#t) or unembed (#f) the object.
+ *
+ * \return         the object (\a obj_s).
+ */
+SCM_DEFINE (set_object_embedded_x, "%set-object-embedded!", 2, 0, 0,
+            (SCM obj_s, SCM embed_s), "Embed or unembed an object.")
+{
+  SCM_ASSERT (EDASCM_OBJECTP (obj_s), obj_s,
+              SCM_ARG1, s_set_object_embedded_x);
+  SCM_ASSERT (scm_is_bool (embed_s), embed_s,
+              SCM_ARG2, s_set_object_embedded_x);
+
+  OBJECT* obj   = edascm_to_object (obj_s);
+  int     embed = scm_is_true (embed_s);
+
+  gboolean component  = obj->type == OBJ_COMPONENT;
+  gboolean picture    = obj->type == OBJ_PICTURE;
+  gboolean embeddable = component || picture;
+
+  if (embeddable)
+  {
+    gboolean  embedded = component ? o_component_is_embedded (obj)
+                                   : o_picture_is_embedded (obj);
+
+    if (embed && !embedded)
+    {
+      o_embed (obj);
+      o_page_changed (obj);
+    }
+    else
+    if (!embed && embedded)
+    {
+      o_unembed (obj);
+      o_page_changed (obj);
+    }
+  }
+
+  return obj_s;
+
+} /* set_object_embedded_x() */
+
+
+
 /*! \brief Create a new line.
  * \par Function Description
  * Creates a new line object, with all its parameters set to default
  * values.
  *
- * \note Scheme API: Implements the %make-line procedure in the (geda
- * core object) module.
+ * \note Scheme API: Implements the %make-line procedure in the
+ * (lepton core object) module.
  *
  * \return a newly-created line object.
  */
@@ -823,8 +901,8 @@ SCM_DEFINE (make_line, "%make-line", 0, 0, 0,
  * \par Function Description
  * Modifies a line object by setting its parameters to new values.
  *
- * \note Scheme API: Implements the %set-line! procedure in the (geda
- * core object) module.
+ * \note Scheme API: Implements the %set-line! procedure in the
+ * (lepton core object) module.
  *
  * This function also works on net, bus and pin objects.  For pins,
  * the start is the connectable point on the pin.
@@ -889,12 +967,12 @@ SCM_DEFINE (set_line_x, "%set-line!", 6, 0, 0,
   o_set_color (toplevel, obj, scm_to_int (color_s));
 
   /* We may need to update connectivity. */
-  PAGE *page = o_get_page (toplevel, obj);
+  PAGE *page = o_get_page (obj);
   if (page != NULL) {
     s_conn_update_object (page, obj);
   }
 
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return line_s;
 }
@@ -947,8 +1025,8 @@ SCM_DEFINE (line_info, "%line-info", 1, 0, 0,
  * Creates a new net object, with all its parameters set to default
  * values.
  *
- * \note Scheme API: Implements the %make-net procedure in the (geda
- * core object) module.
+ * \note Scheme API: Implements the %make-net procedure in the
+ * (lepton core object) module.
  *
  * \return a newly-created net object.
  */
@@ -976,8 +1054,8 @@ SCM_DEFINE (make_net, "%make-net", 0, 0, 0,
  * Creates a new bus object, with all its parameters set to default
  * values.
  *
- * \note Scheme API: Implements the %make-bus procedure in the (geda
- * core object) module.
+ * \note Scheme API: Implements the %make-bus procedure in the
+ * (lepton core object) module.
  *
  * \todo Do we need a way to get/set bus ripper direction?
  *
@@ -1012,8 +1090,8 @@ SCM_DEFINE (make_bus, "%make-bus", 0, 0, 0,
  * values.  type_s is a Scheme symbol indicating whether the pin
  * should be a "net" pin or a "bus" pin.
  *
- * \note Scheme API: Implements the %make-pin procedure in the (geda
- * core object) module.
+ * \note Scheme API: Implements the %make-pin procedure in the
+ * (lepton core object) module.
  *
  * \return a newly-created pin object.
  */
@@ -1056,8 +1134,8 @@ SCM_DEFINE (make_pin, "%make-pin", 1, 0, 0,
  * Returns a symbol describing the pin type of the pin object \a
  * pin_s.
  *
- * \note Scheme API: Implements the %make-pin procedure in the (geda
- * core object) module.
+ * \note Scheme API: Implements the %make-pin procedure in the
+ * (lepton core object) module.
  *
  * \return the symbol 'pin or 'bus.
  */
@@ -1091,8 +1169,8 @@ SCM_DEFINE (pin_type, "%pin-type", 1, 0, 0,
  * Creates a new box object, with all its parameters set to default
  * values.
  *
- * \note Scheme API: Implements the %make-box procedure in the (geda
- * core object) module.
+ * \note Scheme API: Implements the %make-box procedure in the
+ * (lepton core object) module.
  *
  * \return a newly-created box object.
  */
@@ -1116,8 +1194,8 @@ SCM_DEFINE (make_box, "%make-box", 0, 0, 0,
  * \par Function Description
  * Modifies a box object by setting its parameters to new values.
  *
- * \note Scheme API: Implements the %set-box! procedure in the (geda
- * core object) module.
+ * \note Scheme API: Implements the %set-box! procedure in the
+ * (lepton core object) module.
  *
  * \param box_s  the box object to modify.
  * \param x1_s   the new x-coordinate of the top left of the box.
@@ -1148,7 +1226,7 @@ SCM_DEFINE (set_box_x, "%set-box!", 6, 0, 0,
                               scm_to_int (x2_s), scm_to_int (y2_s));
   o_set_color (toplevel, obj, scm_to_int (color_s));
 
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return box_s;
 }
@@ -1190,7 +1268,7 @@ SCM_DEFINE (box_info, "%box-info", 1, 0, 0,
  * values.
  *
  * \note Scheme API: Implements the %make-circle procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \return a newly-created circle object.
  */
@@ -1217,7 +1295,7 @@ SCM_DEFINE (make_circle, "%make-circle", 0, 0, 0,
  * Modifies a circle object by setting its parameters to new values.
  *
  * \note Scheme API: Implements the %set-circle! procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param circle_s the circle object to modify.
  * \param x_s    the new x-coordinate of the center of the circle.
@@ -1246,7 +1324,7 @@ SCM_DEFINE (set_circle_x, "%set-circle!", 5, 0, 0,
   geda_circle_object_modify (toplevel, obj, scm_to_int(r_s), 0, CIRCLE_RADIUS);
   o_set_color (toplevel, obj, scm_to_int (color_s));
 
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return circle_s;
 }
@@ -1286,7 +1364,7 @@ SCM_DEFINE (circle_info, "%circle-info", 1, 0, 0,
  * values.
  *
  * \note Scheme API: Implements the %make-arc procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \return a newly-created arc object.
  */
@@ -1315,7 +1393,7 @@ SCM_DEFINE (make_arc, "%make-arc", 0, 0, 0,
  * Modifies a arc object by setting its parameters to new values.
  *
  * \note Scheme API: Implements the %set-arc! procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param arc_s         the arc object to modify.
  * \param x_s           the new x-coordinate of the center of the arc.
@@ -1352,7 +1430,7 @@ SCM_DEFINE (set_arc_x, "%set-arc!", 7, 0, 0,
   geda_arc_object_modify (toplevel, obj, scm_to_int(end_angle_s), 0, ARC_SWEEP_ANGLE);
   o_set_color (toplevel, obj, scm_to_int (color_s));
 
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return arc_s;
 }
@@ -1370,7 +1448,7 @@ SCM_DEFINE (set_arc_x, "%set-arc!", 7, 0, 0,
  * -# Colormap index of color to be used for drawing the arc
  *
  * \note Scheme API: Implements the %arc-info procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param arc_s the arc object to inspect.
  * \return a list of arc parameters.
@@ -1398,7 +1476,7 @@ SCM_DEFINE (arc_info, "%arc-info", 1, 0, 0,
  * values.
  *
  * \note Scheme API: Implements the %make-text procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \return a newly-created text object.
  */
@@ -1436,7 +1514,7 @@ SCM_DEFINE (make_text, "%make-text", 0, 0, 0,
  * the symbols "name", "value" or "both".
  *
  * \note Scheme API: Implements the %set-text! procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param text_s    the text object to modify.
  * \param x_s       the new x-coordinate of the anchor of the text.
@@ -1547,7 +1625,7 @@ SCM_DEFINE (set_text_x, "%set-text!", 10, 0, 0,
   /* Color */
   o_set_color (toplevel, obj, scm_to_int (color_s));
 
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return text_s;
 }
@@ -1568,7 +1646,7 @@ SCM_DEFINE (set_text_x, "%set-text!", 10, 0, 0,
  * -# Colormap index of color to be used for drawing the text
  *
  * \note Scheme API: Implements the %text-info procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param text_s the text object to inspect.
  * \return a list of text parameters.
@@ -1633,11 +1711,11 @@ SCM_DEFINE (text_info, "%text-info", 1, 0, 0,
  * \par Function Description
  * Returns a list of all objects directly connected to \a obj_s.  If
  * \a obj_s is not included in a page, throws a Scheme error.  If \a
- * obj_s is not a pin, net, bus, or complex object, returns the empty
+ * obj_s is not a pin, net, bus, or component object, returns the empty
  * list.
  *
  * \note Scheme API: Implements the %object-connections procedure of
- * the (geda core object) module.
+ * the (lepton core object) module.
  *
  * \param obj_s #OBJECT smob for object to get connections for.
  * \return a list of #OBJECT smobs.
@@ -1649,9 +1727,8 @@ SCM_DEFINE (object_connections, "%object-connections", 1, 0, 0,
   SCM_ASSERT (edascm_is_object (obj_s), obj_s,
               SCM_ARG1, s_object_connections);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
-  if (o_get_page (toplevel, obj) == NULL) {
+  if (o_get_page (obj) == NULL) {
     scm_error (edascm_object_state_sym,
                s_object_connections,
                _("Object ~A is not included in a page."),
@@ -1664,23 +1741,23 @@ SCM_DEFINE (object_connections, "%object-connections", 1, 0, 0,
   return result;
 }
 
-/*! \brief Get the complex object that contains an object.
+/*! \brief Get the component object that contains an object.
  * \par Function Description
- * Returns the complex object that contains the object \a obj_s.  If
- * \a obj_s is not part of a component, returns SCM_BOOL_F.
+ * Returns the component object that contains the object \a obj_s.
+ * If \a obj_s is not part of a component, returns SCM_BOOL_F.
  *
- * \note Scheme API: Implements the %object-complex procedure of the
- * (geda core object) module.
+ * \note Scheme API: Implements the %object-component procedure of the
+ * (lepton core object) module.
  *
  * \param obj_s #OBJECT smob for object to get component of.
  * \return the #OBJECT smob of the containing component, or SCM_BOOL_F.
  */
-SCM_DEFINE (object_complex, "%object-complex", 1, 0, 0,
-            (SCM obj_s), "Get containing complex object of an object.")
+SCM_DEFINE (object_component, "%object-component", 1, 0, 0,
+            (SCM obj_s), "Get containing component object of an object.")
 {
   /* Ensure that the argument is an object smob */
   SCM_ASSERT (edascm_is_object (obj_s), obj_s,
-              SCM_ARG1, s_object_complex);
+              SCM_ARG1, s_object_component);
 
   TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
@@ -1696,8 +1773,8 @@ SCM_DEFINE (object_complex, "%object-complex", 1, 0, 0,
  * Creates a new, empty path object with default color, stroke and
  * fill options.
  *
- * \note Scheme API: Implements the %make-path procedure in the (geda
- * core object) module.
+ * \note Scheme API: Implements the %make-path procedure in the
+ * (lepton core object) module.
  *
  * \return a newly-created path object.
  */
@@ -1721,7 +1798,7 @@ SCM_DEFINE (make_path, "%make-path", 0, 0, 0,
  * Retrieves the number of path elements in the path object \a obj_s.
  *
  * \note Scheme API: Implements the %path-length procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s #OBJECT smob for path object to inspect.
  * \return The number of path elements in \a obj_s.
@@ -1758,8 +1835,8 @@ SCM_DEFINE (path_length, "%path-length", 1, 0, 0,
  *
  * All coordinates are absolute.
  *
- * \note Scheme API: Implements the %path-ref procedure in the (geda
- * core object) module.
+ * \note Scheme API: Implements the %path-ref procedure in the
+ * (lepton core object) module.
  *
  * \param obj_s   #OBJECT smob of path object to get element from.
  * \param index_s Index of element to retrieve from \a obj_s
@@ -1820,7 +1897,7 @@ SCM_DEFINE (path_ref, "%path-ref", 2, 0, 0,
  * "out-of-range" error.
  *
  * \note Scheme API: Implements the %path-remove! procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s   #OBJECT smob of path object to remove element from.
  * \param index_s Index of element to remove from \a obj_s.
@@ -1861,7 +1938,7 @@ SCM_DEFINE (path_remove_x, "%path-remove!", 2, 0, 0,
   }
 
   o_emit_change_notify (toplevel, obj);
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return obj_s;
 }
@@ -1886,7 +1963,7 @@ SCM_DEFINE (path_remove_x, "%path-remove!", 2, 0, 0,
  * to the path.
  *
  * \note Scheme API: Implements the %path-insert! procedure of the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s   #OBJECT smob for the path object to modify.
  * \param index_s Index at which to insert new element.
@@ -1976,7 +2053,7 @@ SCM_DEFINE (path_insert_x, "%path-insert", 3, 6, 0,
   path->sections[idx] = section;
 
   o_emit_change_notify (toplevel, obj);
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return obj_s;
 }
@@ -1988,7 +2065,7 @@ SCM_DEFINE (path_insert_x, "%path-insert", 3, 6, 0,
  * be embedded.
  *
  * \note Scheme API: Implements the %make-picture procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \return a newly-created picture object.
  */
@@ -2021,7 +2098,7 @@ SCM_DEFINE (make_picture, "%make-picture", 0, 0, 0, (),
  * -# Whether object is mirrored.
  *
  * \note Scheme API: Implements the %picture-info procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s the picture object to inspect.
  * \return a list of picture object parameters.
@@ -2055,7 +2132,7 @@ SCM_DEFINE (picture_info, "%picture-info", 1, 0, 0,
  * Sets the parameters of the picture object \a obj_s.
  *
  * \note Scheme API: Implements the %set-picture! procedure in the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s       the picture object to modify
  * \param x1_s  the new x-coordinate of the top left of the picture.
@@ -2118,7 +2195,7 @@ SCM_DEFINE (set_picture_x, "%set-picture!", 7, 0, 0,
  * format.
  *
  * \note Scheme API: Implements the %set-picture-data/vector!
- * procedure in the (geda core object) module.
+ * procedure in the (lepton core object) module.
  *
  * \param obj_s       The picture object to modify.
  * \param data_s      Vector containing encoded image data.
@@ -2173,7 +2250,7 @@ SCM_DEFINE (set_picture_data_vector_x, "%set-picture-data/vector!",
                     scm_list_1 (scm_from_utf8_string (error->message)));
   }
 
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
   scm_dynwind_end ();
   return obj_s;
 }
@@ -2186,7 +2263,7 @@ SCM_DEFINE (set_picture_data_vector_x, "%set-picture-data/vector!",
  * y-axis.
  *
  * \note Scheme API: Implements the %translate-object! procedure of the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s  #OBJECT smob for object to translate.
  * \param dx_s   Integer distance to translate along x-axis.
@@ -2212,7 +2289,7 @@ SCM_DEFINE (translate_object_x, "%translate-object!", 3, 0, 0,
   o_emit_pre_change_notify (toplevel, obj);
   geda_object_translate (obj, dx, dy);
   o_emit_change_notify (toplevel, obj);
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return obj_s;
 }
@@ -2224,7 +2301,7 @@ SCM_DEFINE (translate_object_x, "%translate-object!", 3, 0, 0,
  * multiple of 90 degrees.
  *
  * \note Scheme API: Implements the %rotate-object! procedure of the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s    #OBJECT smob for object to translate.
  * \param x_s      x-coordinate of centre of rotation.
@@ -2252,8 +2329,8 @@ SCM_DEFINE (rotate_object_x, "%rotate-object!", 4, 0, 0,
   int y = scm_to_int (y_s);
   int angle = scm_to_int (angle_s);
 
-  /* FIXME Work around horribly broken libgeda behaviour.  Some
-   * libgeda functions treat a rotation of -90 degrees as a rotation
+  /* FIXME Work around horribly broken liblepton behaviour.  Some
+   * liblepton functions treat a rotation of -90 degrees as a rotation
    * of +90 degrees, etc., which is not sane. */
   while (angle < 0) angle += 360;
   while (angle >= 360) angle -= 360;
@@ -2263,7 +2340,7 @@ SCM_DEFINE (rotate_object_x, "%rotate-object!", 4, 0, 0,
   o_emit_pre_change_notify (toplevel, obj);
   geda_object_rotate (toplevel, x, y, angle, obj);
   o_emit_change_notify (toplevel, obj);
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return obj_s;
 }
@@ -2273,7 +2350,7 @@ SCM_DEFINE (rotate_object_x, "%rotate-object!", 4, 0, 0,
  * Mirrors \a obj_s in the line x = \a x_s.
  *
  * \note Scheme API: Implements the %mirror-object! procedure of the
- * (geda core object) module.
+ * (lepton core object) module.
  *
  * \param obj_s    #OBJECT smob for object to translate.
  * \param x_s      x-coordinate of centre of rotation.
@@ -2296,49 +2373,76 @@ SCM_DEFINE (mirror_object_x, "%mirror-object!", 2, 0, 0,
   o_emit_pre_change_notify (toplevel, obj);
   geda_object_mirror (toplevel, x, 0, obj);
   o_emit_change_notify (toplevel, obj);
-  o_page_changed (toplevel, obj);
+  o_page_changed (obj);
 
   return obj_s;
 }
 
 /*!
- * \brief Create the (geda core object) Scheme module.
+ * \brief Create the (lepton core object) Scheme module.
  * \par Function Description
- * Defines procedures in the (geda core object) module. The module can
- * be accessed using (use-modules (geda core object)).
+ * Defines procedures in the (lepton core object) module. The module can
+ * be accessed using (use-modules (lepton core object)).
  */
 static void
-init_module_geda_core_object (void *unused)
+init_module_lepton_core_object (void *unused)
 {
   /* Register the functions and symbols */
   #include "scheme_object.x"
 
   /* Add them to the module's public definitions. */
   scm_c_export (s_object_id,
-                s_object_type, s_copy_object, s_object_bounds,
-                s_object_stroke, s_set_object_stroke_x,
-                s_object_fill, s_set_object_fill_x,
-                s_object_color, s_set_object_color_x,
-                s_make_line, s_make_net, s_make_bus,
-                s_make_pin, s_pin_type,
-                s_set_line_x, s_line_info,
-                s_make_box, s_set_box_x, s_box_info,
-                s_make_circle, s_set_circle_x, s_circle_info,
-                s_make_arc, s_set_arc_x, s_arc_info,
-                s_make_text, s_set_text_x, s_text_info,
-                s_object_connections, s_object_complex,
-                s_make_path, s_path_length, s_path_ref,
-                s_path_remove_x, s_path_insert_x,
-                s_make_picture, s_picture_info, s_set_picture_x,
+                s_object_type,
+                s_copy_object,
+                s_object_bounds,
+                s_object_stroke,
+                s_set_object_stroke_x,
+                s_object_fill,
+                s_set_object_fill_x,
+                s_object_color,
+                s_set_object_color_x,
+                s_make_line,
+                s_make_net,
+                s_make_bus,
+                s_make_pin,
+                s_pin_type,
+                s_set_line_x,
+                s_line_info,
+                s_make_box,
+                s_set_box_x,
+                s_box_info,
+                s_make_circle,
+                s_set_circle_x,
+                s_circle_info,
+                s_make_arc,
+                s_set_arc_x,
+                s_arc_info,
+                s_make_text,
+                s_set_text_x,
+                s_text_info,
+                s_object_connections,
+                s_object_component,
+                s_make_path,
+                s_path_length,
+                s_path_ref,
+                s_path_remove_x,
+                s_path_insert_x,
+                s_make_picture,
+                s_picture_info,
+                s_set_picture_x,
                 s_set_picture_data_vector_x,
-                s_translate_object_x, s_rotate_object_x,
+                s_translate_object_x,
+                s_rotate_object_x,
                 s_mirror_object_x,
-                s_object_selectable_p, s_set_object_selectable_x,
+                s_object_selectable_p,
+                s_set_object_selectable_x,
+                s_object_embedded_p,
+                s_set_object_embedded_x,
                 NULL);
 }
 
 /*!
- * \brief Initialise the basic gEDA object manipulation procedures.
+ * \brief Initialise the basic Lepton EDA object manipulation procedures.
  * \par Function Description
  * Registers some Scheme procedures for working with #OBJECT
  * smobs. Should only be called by edascm_init().
@@ -2346,8 +2450,8 @@ init_module_geda_core_object (void *unused)
 void
 edascm_init_object ()
 {
-  /* Define the (geda core object) module */
-  scm_c_define_module ("geda core object",
-                       (void (*) (void*)) init_module_geda_core_object,
+  /* Define the (lepton core object) module */
+  scm_c_define_module ("lepton core object",
+                       (void (*) (void*)) init_module_lepton_core_object,
                        NULL);
 }
