@@ -1,6 +1,6 @@
 /* libleptonrenderer - Rendering Lepton EDA schematics with Cairo
  * Copyright (C) 2010-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -149,7 +149,7 @@ static int eda_renderer_prepare_text (EdaRenderer *renderer, const GedaObject *o
 static void eda_renderer_calc_text_position (EdaRenderer *renderer, const GedaObject *object,
                                              int descent, double *x, double *y);
 static void eda_renderer_draw_picture (EdaRenderer *renderer, OBJECT *object);
-static void eda_renderer_draw_complex (EdaRenderer *renderer, OBJECT *object);
+static void eda_renderer_draw_component (EdaRenderer *renderer, OBJECT *object);
 
 static void eda_renderer_default_draw_grips (EdaRenderer *renderer, OBJECT *object);
 static void eda_renderer_draw_grips_list (EdaRenderer *renderer, GList *objects) G_GNUC_UNUSED;
@@ -523,8 +523,8 @@ eda_renderer_default_draw (EdaRenderer *renderer, OBJECT *object)
   case OBJ_TEXT:        draw_func = eda_renderer_draw_text; break;
   case OBJ_PICTURE:     draw_func = eda_renderer_draw_picture; break;
 
-  case OBJ_COMPLEX:
-  case OBJ_PLACEHOLDER: draw_func = eda_renderer_draw_complex; break;
+  case OBJ_COMPONENT:
+  case OBJ_PLACEHOLDER: draw_func = eda_renderer_draw_component; break;
 
   default:
     g_return_if_reached ();
@@ -566,8 +566,8 @@ eda_renderer_is_drawable (EdaRenderer *renderer, OBJECT *object)
 {
   int color = geda_object_get_drawing_color (object);
 
-  /* Always attempt to draw complex objects */
-  if ((object->type == OBJ_COMPLEX) || (object->type == OBJ_PLACEHOLDER)) {
+  /* Always attempt to draw component objects */
+  if ((object->type == OBJ_COMPONENT) || (object->type == OBJ_PLACEHOLDER)) {
     return TRUE;
   }
   return eda_renderer_is_drawable_color (renderer, color, TRUE);
@@ -638,10 +638,10 @@ eda_renderer_draw_hatch (EdaRenderer *renderer, OBJECT *object)
 }
 
 static void
-eda_renderer_draw_complex (EdaRenderer *renderer, OBJECT *object)
+eda_renderer_draw_component (EdaRenderer *renderer, OBJECT *object)
 {
   /* Recurse */
-  eda_renderer_draw_list (renderer, object->complex->prim_objs);
+  eda_renderer_draw_list (renderer, object->component->prim_objs);
 }
 
 static void
@@ -1151,7 +1151,7 @@ eda_renderer_default_draw_grips (EdaRenderer *renderer, OBJECT *object)
         object->picture->upper_x, object->picture->lower_y,
         object->picture->lower_x, object->picture->lower_y);
     break;
-  case OBJ_COMPLEX:
+  case OBJ_COMPONENT:
   case OBJ_PLACEHOLDER:
     /* No grips */
     break;
@@ -1354,10 +1354,10 @@ eda_renderer_default_draw_cues (EdaRenderer *renderer, OBJECT *object)
   case OBJ_TEXT:
   case OBJ_PICTURE:
     break;
-  case OBJ_COMPLEX:
+  case OBJ_COMPONENT:
   case OBJ_PLACEHOLDER:
     /* Recurse */
-    eda_renderer_draw_cues_list (renderer, object->complex->prim_objs);
+    eda_renderer_draw_cues_list (renderer, object->component->prim_objs);
     break;
   case OBJ_NET:
   case OBJ_BUS:
@@ -1514,7 +1514,7 @@ eda_renderer_default_get_user_bounds (EdaRenderer *renderer,
   case OBJ_CIRCLE:
   case OBJ_PATH:
   case OBJ_PICTURE:
-  case OBJ_COMPLEX:
+  case OBJ_COMPONENT:
   case OBJ_PLACEHOLDER:
   case OBJ_NET:
   case OBJ_BUS:
