@@ -1,7 +1,7 @@
 ;;; Lepton EDA netlister
 ;;; Copyright (C) 1998-2010 Ales Hvezda
 ;;; Copyright (C) 1998-2017 gEDA Contributors
-;;; Copyright (C) 2018-2019 Lepton EDA Contributors
+;;; Copyright (C) 2018-2020 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -32,6 +32,8 @@
 ;; Project started 3.5.2003 -- SDB.
 ;;
 ;; Details and documentation at http://www.brorson.com/gEDA/SPICE/
+;; NOTE: This link doesn't work (October 2019), see the docs here:
+;;       http://wiki.geda-project.org/geda:csygas
 ;;
 ;;  Change log:
 ;;  3.5.2003 -- Started hacking.  SDB.
@@ -209,14 +211,14 @@
     (and (string-ci=? (gnetlist:get-package-attribute package "device")
                       "spice-io")
          package))
-  (filter-map spice-io? ls))
+  (filter-map spice-io? package-list))
 
 
 ;;; Given a list of spice-IO packages (refdeses), this function
 ;;; returns the list of nets attached to the IOs.
 (define (spice-sdb:get-io-nets package-list)
   (map
-   (lambda (package) (package-pin-netname package "1"))
+   (lambda (package) (pin-netname package "1"))
    package-list))
 
 
@@ -349,7 +351,7 @@
 
     ;; Now write out any model which is pointed to by the part.
     (when (not (unknown? model))
-      (format #t ".MODEL ~A ~A (~A)\n" model-name type package-model))))
+      (format #t ".MODEL ~A ~A (~A)\n" model-name type model))))
 
 
 ;;  Writes diode SPICE card for PACKAGE.
@@ -855,9 +857,9 @@
   (format #t "* ~A
 *********************************************************
 * Spice file generated by lepton-netlist                *
-* spice-sdb version 4.28.2007 by SDB --                 *
+* spice-sdb by SDB                                      *
 * provides advanced spice netlisting capability.        *
-* Documentation at http://www.brorson.com/gEDA/SPICE/   *
+* Documentation at wiki.geda-project.org/geda:csygas    *
 *********************************************************
 "
           (get-command-line)))
@@ -872,7 +874,7 @@
          (io-nets-list (spice-sdb:get-io-nets io-pin-packages-ordered)))
     (format #t "*******************************
 * Begin .SUBCKT model         *
-* spice-sdb ver 4.28.2007     *
+* spice-sdb by SDB            *
 *******************************
 .SUBCKT ~A
 "
@@ -905,6 +907,16 @@ the name is changed to canonical."
 "
           subckt-name))
 
+
+; public:
+; Instruct the netlister to use 'spice mode
+;
+( define ( request-netlist-mode )
+  ; return:
+  'spice
+)
+
+
 ;;---------------------------------------------------------------
 ;; Spice netlist generation
 ;;   This is the entry point.
@@ -938,7 +950,7 @@ the name is changed to canonical."
   ;; Redefine write-net-names-on-component
   (set! spice:write-net-names-on-component spice-sdb:write-net-names-on-component)
 
-  (message "Using SPICE backend by SDB -- Version of 4.28.2007\n")
+  (message "Using SPICE backend by SDB\n")
 
   ;; First find out if this is a .SUBCKT lower level,
   ;; or if it is a regular schematic.
