@@ -1,7 +1,7 @@
 ;;; Lepton EDA netlister
 ;;; Copyright (C) 1998-2010 Ales Hvezda
 ;;; Copyright (C) 1998-2017 gEDA Contributors
-;;; Copyright (C) 2018-2019 Lepton EDA Contributors
+;;; Copyright (C) 2018-2020 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -768,7 +768,7 @@ ARCHITECTURE ~A OF ~A IS
 ;;; REFDES-LIST.
 (define (vams:all-packages-nets refdes-list)
   (define (pin-net-names package)
-    (map (cut package-pin-netname package <>)
+    (map (cut pin-netname package <>)
          (get-pins package)))
 
   (map pin-net-names refdes-list))
@@ -830,7 +830,7 @@ ARCHITECTURE ~A OF ~A IS
     (car (get-pins port)))
 
   (define (first-pin-net port)
-    (package-pin-netname port (first-pin port)))
+    (pin-netname port (first-pin port)))
 
   (if (null? ports)
       '()
