@@ -1,7 +1,7 @@
 ;;; Lepton EDA netlister
 ;;; Copyright (C) 1998-2010 Ales Hvezda
 ;;; Copyright (C) 1998-2017 gEDA Contributors
-;;; Copyright (C) 2017-2018 Lepton EDA Contributors
+;;; Copyright (C) 2017-2020 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -71,8 +71,7 @@
   (define (get-package-pin-netnames package)
     (and (string=? (gnetlist:get-package-attribute package attribute)
                    value)
-         (package-pin-netname package
-                              (car (get-pins package)))))
+         (pin-netname package (car (get-pins package)))))
 
   (filter-map get-package-pin-netnames package-list))
 
@@ -152,12 +151,8 @@
     (begin
       (display "/* structural Verilog generated by lepton-netlist */\n")
       (display "/* WARNING: This is a generated file, edits       */\n")
-      (display "/*        made here will be lost next time        */\n")
-      (display "/*        you run gnetlist!                       */\n")
-      (display "/* Id ..........$Id$ */\n")
-      (display "/* Source.......$Source$ */\n")
-      (display "/* Revision.....$Revision$ */\n")
-      (display "/* Author.......$Author$ */\n")
+      (display "/*          made here will be lost next time      */\n")
+      (display "/*          you run netlister!                    */\n")
       (newline)
       (verilog:write-module-declaration module-name port-list)
       (newline)
