@@ -1,7 +1,7 @@
 ;;; Lepton EDA netlister
 ;;; Copyright (C) 1998-2010 Ales Hvezda
 ;;; Copyright (C) 1998-2017 gEDA Contributors
-;;; Copyright (C) 2017-2019 Lepton EDA Contributors
+;;; Copyright (C) 2017-2020 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -26,26 +26,29 @@
   #:use-module (ice-9 ftw)
   #:use-module (ice-9 i18n)
   #:use-module (ice-9 regex)
+  #:use-module (netlist duplicate)
+  #:use-module (netlist net)
   #:use-module (netlist option)
   #:use-module (netlist schematic-component)
-  #:use-module (netlist sort)
+  #:use-module (netlist schematic-connection)
   #:use-module (netlist attrib compare)
-  #:use-module (geda page)
+  #:use-module (netlist attrib refdes)
   #:use-module (geda deprecated)
-  #:use-module (geda log)
-  #:use-module (geda repl)
   #:use-module (lepton library)
+  #:use-module (lepton log)
+  #:use-module (lepton object)
+  #:use-module (lepton page)
+  #:use-module (lepton repl)
   #:use-module (lepton version)
   #:use-module (netlist core gettext)
   #:use-module (netlist config)
   #:use-module (netlist deprecated)
   #:use-module (netlist error)
+  #:use-module (netlist mode)
   #:use-module (netlist schematic)
   #:use-module (netlist package-pin)
-  #:use-module (netlist pin-net)
   #:use-module (netlist schematic toplevel)
   #:use-module (netlist verbose)
-  #:use-module ((netlist rename) #:select (get-rename-list))
 
   #:export (lepton-netlist-version
             main
@@ -58,7 +61,7 @@
             get-nets
             get-pins-nets
             message
-            package-pin-netname
+            pin-netname
             gnetlist:alias-net
             gnetlist:alias-refdes
             gnetlist:build-net-aliases
@@ -101,14 +104,14 @@ to current standard output port and exit with exit status 0."
   (define version-msg "Lepton EDA/lepton-netlist ~A~A.~A (git: ~A)\n")
 
   (define copyright-msg (_ "Copyright (C) 1998-2016 gEDA developers
-Copyright (C) 2017-2019 Lepton EDA Contributors
+Copyright (C) 2017-2020 Lepton EDA Contributors
 This is free software, and you are welcome to redistribute it under
 certain conditions. For details, see the file `COPYING', which is
 included in the Lepton EDA distribution.
 There is NO WARRANTY, to the extent permitted by law.\n"))
 
   (match (lepton-version)
-    ((prepend dotted date commit)
+    ((prepend dotted date commit bugs url msg)
      (if output-to-log?
          (log! 'message version-msg prepend dotted date (string-take commit 7))
          (begin
@@ -243,7 +246,7 @@ REFDES. As a result, slots may be repeated in the returned list."
               ;; conversion failed, invalid slot, ignore value
               (begin
                 (format (current-error-port)
-                        (_ "Uref ~a: Bad slot number: ~a.\n") refdes slot)
+                        (_ "Refdes ~a: Bad slot number: ~a.\n") refdes slot)
                 #f))
           ;; no slot attribute, assume slot number is 1
           1))
@@ -343,8 +346,8 @@ REFDES. As a result, slots may be repeated in the returned list."
 
 ;;; Helper function for sorting connections.
 (define (pair<? a b)
-  (let ((refdes-a (schematic-component-refdes->string (car a)))
-        (refdes-b (schematic-component-refdes->string (car b)))
+  (let ((refdes-a (hierarchical-refdes->string (car a)))
+        (refdes-b (hierarchical-refdes->string (car b)))
         (pin-a (cdr a))
         (pin-b (cdr b)))
     (or (refdes<? refdes-a refdes-b)
@@ -362,24 +365,22 @@ NETNAME in SCHEMATIC."
 
   (define netlist (schematic-components schematic))
 
-  (define non-graphical-refdeses
-    (filter-map schematic-component-refdes netlist))
-
-  (define (refdes->string refdes)
-    (let ((refdes (schematic-component-refdes->string refdes)))
-      (and (member refdes non-graphical-refdeses)
-           refdes)))
+  (define (pin->refdes-pinnumber-pair pin)
+    (let* ((component (package-pin-parent pin))
+           (refdes (hierarchical-refdes->string
+                    (schematic-component-refdes component)))
+           (pinnumber (package-pin-number pin)))
+      (and (not (schematic-component-graphical? component))
+           refdes
+           pinnumber
+           (cons refdes pinnumber))))
 
   (define (get-found-pin-connections pin)
     (if (found? (package-pin-name pin))
-        (filter-map
-         (lambda (net)
-           (let ((refdes (refdes->string (pin-net-connection-package net)))
-                 (pinnumber (pin-net-connection-pinnumber net)))
-             (and refdes
-                  pinnumber
-                  (cons refdes pinnumber))))
-         (package-pin-nets pin))
+        (filter-map pin->refdes-pinnumber-pair
+                    (if (package-pin-connection pin)
+                        (schematic-connection-pins (package-pin-connection pin))
+                        '()))
         '()))
 
   (define (get-netlist-connections netlist)
@@ -397,14 +398,12 @@ NETNAME."
   (get-connections netname (toplevel-schematic)))
 
 
-(define (get-pins-nets package)
-  "Returns a list of pairs (pin-name . net-name) where net-name is
-the name of the net connected to the pin pin-name for specified
-PACKAGE."
+(define (get-pins-nets refdes)
+  "For specified REFDES, returns a list of strings defining
+connection pairs in the form (\"pin-number\" . \"net-name\")."
 
   (define (found? x)
-    (and x
-         (string=? x package)))
+    (string= x refdes))
 
   (define (get-pin-netname-pair pin)
     (let ((pin-number (package-pin-number pin))
@@ -413,9 +412,9 @@ PACKAGE."
            pin-name
            (cons pin-number pin-name))))
 
-  (define (get-pin-netname-list package)
-     (if (found? (schematic-component-refdes package))
-         (filter-map get-pin-netname-pair (schematic-component-pins package))
+  (define (get-pin-netname-list component)
+     (if (and=> (schematic-component-refdes component) found?)
+         (filter-map get-pin-netname-pair (schematic-component-pins component))
          '()))
 
   ;; Currently, netlist can contain many `packages' with the same
@@ -429,18 +428,22 @@ PACKAGE."
 ;;; It should first search for netname, and then get all
 ;;; package-pin pairs by that netname.
 (define (get-nets package pin-number)
-  (define (net-connections nets)
-    (filter-map
-     (lambda (net)
-       (let ((package (pin-net-connection-package net))
-             (pinnumber (pin-net-connection-pinnumber net)))
-         (and package
-              pinnumber
-              (cons package pinnumber))))
-     nets))
+  (define (pin-connections pin)
+    (let ((pins (schematic-connection-pins (package-pin-connection pin))))
+      (filter-map
+       (lambda (pin)
+         (let ((refdes (hierarchical-refdes->string
+                        (schematic-component-refdes (package-pin-parent pin))))
+               (pinnumber (package-pin-number pin)))
+           (and refdes
+                pinnumber
+                (or (package-pin-net-map pin)
+                    (not (null? (cdr pins))))
+                (cons refdes pinnumber))))
+       pins)))
 
-  (define (lookup-through-nets nets package pin-number)
-    (let ((connections (net-connections nets)))
+  (define (lookup-through-connections pin package pin-number)
+    (let ((connections (pin-connections pin)))
       (and (not (null? connections))
            (member (cons package pin-number) connections)
            connections)))
@@ -454,9 +457,9 @@ PACKAGE."
      (lambda (pin)
        (and (found-pin-number? (package-pin-number pin))
             (cons (package-pin-name pin)
-                  (lookup-through-nets (package-pin-nets pin)
-                                       package
-                                       pin-number))))
+                  (lookup-through-connections pin
+                                              package
+                                              pin-number))))
      pins))
 
   (define (found-package? x)
@@ -473,13 +476,12 @@ PACKAGE."
 
   (let ((found (lookup-through-netlist (schematic-components (toplevel-schematic)))))
     (match found
-      (() '("ERROR_INVALID_PIN"))
-      (((netname . rest) ...)
-       (cons (car netname) (append-map identity (filter-map identity rest))))
+      (((netname . rest) ..1)
+       (cons (car netname) (apply append (delq #f rest))))
       (_ '("ERROR_INVALID_PIN")))))
 
 
-(define (package-pin-netname package pinnumber)
+(define (pin-netname package pinnumber)
   (or (assoc-ref (get-pins-nets package) pinnumber)
       "ERROR_INVALID_PIN"))
 
@@ -515,14 +517,43 @@ PACKAGE."
        (get-all-connections netname)))
 (define (gnetlist:get-backend-arguments)
   (netlist-option-ref 'backend-option))
+
 (define (gnetlist:get-renamed-nets level)
-  (map
-   (lambda (rename)
-     (match rename
-       ((src . dest)
-        (list src dest))
-       (_ #f)))
-   (get-rename-list)))
+  "Return the sorted list of net renames in toplevel schematic.
+The argument LEVEL is dummy."
+  (define (make-special-netname connection hname)
+    (let* ((object (car (schematic-connection-objects connection)))
+           (coord (line-start object)))
+      (create-net-name
+       (format #f "unnamed_net_at_~Ax~A" (car coord) (cdr coord))
+       hname
+       #f)))
+
+  (define (unnamed? name)
+    (eq? 'unnamed (car name)))
+
+  (define (name<? a b)
+    (refdes<? (schematic-connection-override-name a)
+              (schematic-connection-override-name b)))
+
+  (define (net? name)
+    (eq? 'net (car name)))
+
+  (define (create-net-name* connection hname)
+    (if (unnamed? hname)
+        (make-special-netname connection (cdr hname))
+        (create-net-name (cadr hname) (cddr hname) (net? hname))))
+
+  (let ((connections (sort (schematic-connections (toplevel-schematic))
+                           name<?)))
+    (append-map
+     (lambda (connection)
+       (let ((common-name (schematic-connection-override-name connection))
+             (other-names (map (cut create-net-name* connection <>)
+                               (cdr (schematic-connection-name connection)))))
+
+         (map (cut list <> common-name) other-names)))
+     connections)))
 
 ;;
 ;; Functions for dealing with naming requirements for different
@@ -805,21 +836,21 @@ begins with \"gnet-\" and ends with \".scm\"."
 Generate a netlist from one or more Lepton EDA schematic FILEs.
 
 General options:
-  -q              Quiet mode.
-  -v, --verbose   Verbose mode.
-  -o FILE         Filename for netlist data output.
-  -L DIR          Add DIR to Scheme search path.
-  -g BACKEND      Specify netlist backend to use.
-  -f FILE         Specify path to netlist backend file to use.
-  -O STRING       Pass an option string to backend.
-  -l FILE         Load Scheme file before loading backend.
-  -m FILE         Load Scheme file after loading backend.
-  -c EXPR         Evaluate Scheme expression at startup.
-  -i              Enter interactive Scheme REPL after loading.
-  --list-backends Print a list of available netlist backends.
-  -h, --help      Help; this message.
-  -V, --version   Show version information.
-  --              Treat all remaining arguments as filenames.
+  -q                  Quiet mode.
+  -v, --verbose       Verbose mode.
+  -o FILE             Filename for netlist data output.
+  -L DIR              Add DIR to Scheme search path.
+  -g BACKEND          Specify netlist backend to use.
+  -f FILE             Specify path to netlist backend file to use.
+  -O STRING           Pass an option string to backend.
+  -l FILE             Load Scheme file before loading backend.
+  -m FILE             Load Scheme file after loading backend.
+  -c EXPR             Evaluate Scheme expression at startup.
+  -i                  Enter interactive Scheme REPL after loading.
+  -b, --list-backends Print a list of available netlist backends.
+  -h, --help          Help; this message.
+  -V, --version       Show version information.
+  --                  Treat all remaining arguments as filenames.
 
 Report bugs at <https://github.com/lepton-eda/lepton-eda/issues>
 Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
@@ -830,11 +861,11 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
 
 ;;; Set lepton-netlist toplevel schematic based on schematic FILES
 ;;; and NETLIST-MODE which must be either "'geda", or "'spice".
-(define (set-ln-toplevel-schematic! files netlist-mode)
-  (and (eq? netlist-mode 'spice)
+(define (set-ln-toplevel-schematic! files)
+  (and (eq? (netlist-mode) 'spice)
        (set! get-uref get-spice-refdes))
   (for-each process-gafrc files)
-  (set-toplevel-schematic! (make-toplevel-schematic files netlist-mode)))
+  (set-toplevel-schematic! (make-toplevel-schematic files)))
 
 
 (define (catch-handler tag . args)
@@ -872,7 +903,6 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
   ( opt-list-backends (netlist-option-ref 'list-backends) ) ; --list-backends
   ( opt-pre-load      (netlist-option-ref 'pre-load) )      ; -l
   ( opt-post-load     (netlist-option-ref 'post-load) )     ; -m
-  ( netlist-mode      'geda )
   ( backend-path      #f )
   ( schematic         #f )
   ( backend-proc-name #f )
@@ -903,6 +933,10 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
                      bname)
   )
 
+  ( define ( error-backend-mode mode )
+    (netlist-error 1 (_ "Netlist mode requested by backend is not supported: ~A\n") mode)
+  )
+
   ( define ( get-backend-proc-name filename )
   ( let*
     (
@@ -918,16 +952,38 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
   )
   )
 
+  ; Backend can request what netlist mode should be used
+  ; by providing request-netlist-mode() function, that
+  ; returns the desired mode:
+  ;
+  ( define ( query-backend-mode )
+  ( let*
+    (
+    ( proc-name 'request-netlist-mode )
+    ( proc      (module-variable (current-module) proc-name) )
+    ( mode      #f )
+    )
+
+    ( when proc
+      ( set! proc ( primitive-eval proc-name ) )
+      ( set! mode ( proc ) )
+
+      ( if ( netlist-mode? mode )
+        ( set-netlist-mode!  mode ) ; if
+        ( error-backend-mode mode ) ; else
+      )
+    )
+  )
+  )
+
 
   ; Parse configuration:
   ;
   ( (@@ (guile-user) parse-rc) "lepton-netlist" "gnetlistrc" )
 
-  ; This is a kludge to make sure that spice mode gets set:
+  ; Set default netlist mode:
   ;
-  ( when ( and opt-backend (string-prefix? "spice" opt-backend) )
-    ( set! netlist-mode 'spice )
-  )
+  ( set-netlist-mode! (default-netlist-mode) )
 
   ; Evaluate Scheme expression at startup (-c EXPR):
   ;
@@ -997,6 +1053,7 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
     ( catch #t
       ( lambda()
         ( primitive-load backend-path )
+        ( query-backend-mode )
       )
       ( lambda( tag . args )
         ( catch-handler tag args )
@@ -1031,7 +1088,7 @@ Lepton EDA homepage: <https://github.com/lepton-eda/lepton-eda>
 
   ; This sets [toplevel-schematic] global variable:
   ;
-  ( set! schematic (set-ln-toplevel-schematic! files netlist-mode) )
+  (set! schematic (set-ln-toplevel-schematic! files))
 
   ; Verbose mode (-v): print internal netlist representation:
   ;
