@@ -1,5 +1,5 @@
 ;;; Lepton EDA netlister
-;;; Copyright (C) 2017-2018 Lepton EDA Contributors
+;;; Copyright (C) 2017-2020 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -19,57 +19,46 @@
 (define-module (netlist net)
   #:use-module (ice-9 match)
   #:use-module (srfi srfi-1)
-  #:use-module (geda attrib)
-  #:use-module (geda log)
-  #:use-module (geda object)
+  #:use-module (lepton attrib)
+  #:use-module (lepton log)
+  #:use-module (lepton object)
   #:use-module (netlist config)
   #:use-module (netlist core gettext)
-  #:use-module (netlist hierarchy)
   #:use-module (symbol check net-attrib)
   #:use-module (symbol check duplicate)
 
-  #:export (create-netattrib
-            create-netname
-            create-net-netname
+  #:export (create-net-name
             netattrib-search-net
             check-net-maps
             attrib-value-by-name))
 
-(define (hierarchy-tag->string hierarchy-tag separator reverse-order?)
-  (match hierarchy-tag
-    ;; Hierarchy tag is already reversed, so we have to reverse it
-    ;; again if no reverse-order? is set.
-    ((? list? tag) (string-join (if reverse-order? tag (reverse tag))
-                                (or separator "")))
-    (tag tag)))
+(define (hierarchical-name->string name separator reverse?)
+  ;; Hierarchical name is already reversed, so we have to
+  ;; reverse it again if no reverse? is set.
+  (string-join (if reverse? name (reverse name))
+               (or separator "")))
 
-(define (create-netattrib basename hierarchy-tag)
-  (define mangle? (gnetlist-config-ref 'mangle-net))
-  (define reverse-order?  (gnetlist-config-ref 'reverse-net-order))
-  (define separator (gnetlist-config-ref 'net-separator))
+(define (create-net-name basename
+                         hierarchy-tag
+                         power-rail?)
+  "Create string representing net name using BASENAME and
+HIERARCHY-TAG.  If POWER-RAIL? is #t, the procedure creates the
+name using settings for \"net=\" attribute which is used in power
+symbols to assign net name. Otherwise, settings for \"netname=\"
+attribute are used, the latter is used to assign names for net
+primitives."
+  (define hierarchical?
+    (gnetlist-config-ref (if power-rail? 'mangle-net 'mangle-netname)))
+  (define reverse?
+    (gnetlist-config-ref (if power-rail? 'reverse-net-order 'reverse-netname-order)))
+  (define separator
+    (gnetlist-config-ref (if power-rail? 'net-separator 'netname-separator)))
+  (define name (cons basename hierarchy-tag))
 
-  (let ((hierarchy-tag (hierarchy-tag->string hierarchy-tag
-                                              separator
-                                              reverse-order?)))
-   (if (and hierarchy-tag mangle? basename)
-       (if reverse-order?
-           (string-append basename (or separator "") hierarchy-tag)
-           (string-append hierarchy-tag (or separator "") basename))
-       basename)))
+  (if (and basename hierarchical?)
+      (hierarchical-name->string name separator reverse?)
+      basename))
 
-(define (create-netname basename hierarchy-tag)
-  (define mangle? (gnetlist-config-ref 'mangle-netname))
-  (define reverse-order?  (gnetlist-config-ref 'reverse-netname-order))
-  (define separator (gnetlist-config-ref 'netname-separator))
-
-  (let ((hierarchy-tag (hierarchy-tag->string hierarchy-tag
-                                              separator
-                                              reverse-order?)))
-   (if (and hierarchy-tag mangle? basename)
-       (if reverse-order?
-           (string-append basename (or separator "") hierarchy-tag)
-           (string-append hierarchy-tag (or separator "") basename))
-       basename)))
 
 (define (attrib-value-by-name object name)
   (define (has-appropriate-name? attrib)
@@ -81,11 +70,6 @@
   (first* (map attrib-value
                (filter has-appropriate-name? (object-attribs object)))))
 
-(define (create-net-netname object hierarchy-tag)
-  ;; Ignore netname= attributes on any objects apart from nets.
-  (and (net? object)
-       (let ((netname (attrib-value-by-name object "netname")))
-         (and netname (create-netname netname hierarchy-tag)))))
 
 (define (blame-missing-colon net-attrib-value)
   (log! 'critical
