@@ -1,6 +1,6 @@
 ;;; Lepton EDA netlister
 ;;; Copyright (C) 2016-2017 gEDA Contributors
-;;; Copyright (C) 2017-2019 Lepton EDA Contributors
+;;; Copyright (C) 2017-2020 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
   #:use-module (ice-9 match)
   #:use-module (srfi srfi-9)
   #:use-module (srfi srfi-9 gnu)
+  #:use-module (lepton attrib)
+  #:use-module (lepton object)
 
   #:export-syntax (make-package-pin package-pin?
                    package-pin-id set-package-pin-id!
@@ -29,13 +31,18 @@
                    package-pin-name set-package-pin-name!
                    package-pin-label set-package-pin-label!
                    package-pin-attribs set-package-pin-attribs!
-                   package-pin-nets set-package-pin-nets!
-                   package-pin-connection set-package-pin-connection!)
+                   package-pin-net-map set-package-pin-net-map!
+                   package-pin-parent set-package-pin-parent!
+                   package-pin-connection set-package-pin-connection!
+                   package-pin-named-connection set-package-pin-named-connection!
+                   package-pin-port-connection set-package-pin-port-connection!)
 
-  #:export (set-package-pin-printer!))
+  #:export (object->package-pin
+            set-package-pin-printer!
+            set-package-pin-parent-component!))
 
 (define-record-type <package-pin>
-  (make-package-pin id object number name label attribs nets connection)
+  (make-package-pin id object number name label attribs net-map parent connection named-connection port-connection)
   package-pin?
   ;; This field is used just for the record representation in
   ;; set-record-type-printer! below.
@@ -50,10 +57,16 @@
   (label package-pin-label set-package-pin-label!)
   ;; The alist representing attributes of the underlying object.
   (attribs package-pin-attribs set-package-pin-attribs!)
-  ;; The list of <pin-net>'s connected to the pin.
-  (nets package-pin-nets set-package-pin-nets!)
+  ;; net= attribute mapping for the pin.
+  (net-map package-pin-net-map set-package-pin-net-map!)
+  ;; Parent component of the pin.
+  (parent package-pin-parent set-package-pin-parent!)
   ;; <schematic-connection> the pin is connected to.
-  (connection package-pin-connection set-package-pin-connection!))
+  (connection package-pin-connection set-package-pin-connection!)
+  ;; Common net name <schematic-connection> the pin is connected to.
+  (named-connection package-pin-named-connection set-package-pin-named-connection!)
+  ;; Hierarchical (via port) <schematic-connection> the pin is connected to.
+  (port-connection package-pin-port-connection set-package-pin-port-connection!))
 
 ;;; Sets default printer for <package-pin>
 (set-record-type-printer!
@@ -70,8 +83,11 @@ FORMAT-STRING must be in the form required by the procedure
   'name
   'label
   'attribs
-  'nets
+  'net-map
+  'parent
   'connection
+  'named-connection
+  'port-connection
 Any other unrecognized argument will lead to yielding '?' in the
 corresponding place.
 Example usage:
@@ -89,7 +105,46 @@ Example usage:
                  ('name (package-pin-name record))
                  ('label (package-pin-label record))
                  ('attribs (package-pin-attribs record))
-                 ('nets (package-pin-nets record))
+                 ('net-map (package-pin-net-map record))
+                 ('parent (package-pin-parent record))
                  ('connection (package-pin-connection record))
+                 ('named-connection (package-pin-named-connection record))
+                 ('port-connection (package-pin-port-connection record))
                  (_ #\?)))
              args)))))
+
+(define (set-package-pin-parent-component! pin component)
+  (delay (set-package-pin-parent! pin component)))
+
+
+(define (object->package-pin pin-object)
+  "Transform a primitive PIN-OBJECT into <package-pin>."
+  (define (add-attrib attrib)
+    (cons (string->symbol (attrib-name attrib))
+          (attrib-value attrib)))
+
+  (define attribs
+    (map add-attrib (object-attribs pin-object)))
+
+  (and (net-pin? pin-object)
+       (make-package-pin (object-id pin-object)
+                         ;; Primitive pin object.
+                         pin-object
+                         ;; Number.
+                         (assq-ref attribs 'pinnumber)
+                         ;; Add name later.
+                         #f
+                         ;; Label.
+                         (assq-ref attribs 'pinlabel)
+                         ;; Attributes.
+                         attribs
+                         ;; No net-map yet.
+                         #f
+                         ;; Set parent component later.
+                         #f
+                         ;; No connection yet.
+                         #f
+                         ;; No netname connection yet.
+                         #f
+                         ;; No port connection yet.
+                         #f)))
