@@ -1,6 +1,6 @@
 ;;; Autotools compatible SRFI-64 Scheme unit-test framework
 ;;; Copyright (C) 2016 gEDA Contributors
-;;; Copyright (C) 2018-2019 Lepton EDA Contributors
+;;; Copyright (C) 2018-2020 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -54,16 +54,29 @@
 ;;;   Must be present once if several tests are done in one
 ;;;   script. It should output some summary.
 
-
 (use-modules (srfi srfi-64)
              (srfi srfi-26)
              (ice-9 getopt-long)
              (ice-9 pretty-print))
 
+;;; In order to facilitate debugging, you can increase the pile of
+;;; info reported on errors by setting the COLUMNS environment
+;;; variable to a bigger value. Example:
+;; (setenv "COLUMNS" "1000")
+
+
 ;;; Initialize liblepton variables and functions.
-(load-extension "../../liblepton/src/liblepton" "libgeda_init")
-(define with-toplevel (@@ (geda core toplevel) %with-toplevel))
-(define make-toplevel (@@ (geda core toplevel) %make-toplevel))
+(setenv "LEPTON_INHIBIT_RC_FILES" "yes")
+;;; The load path should not be changed after loading the
+;;; liblepton library.  This is tested in the unit test
+;;; "test-netlist-load-path.scm".
+(setenv "INITIAL_GUILE_LOAD_PATH"
+        (with-output-to-string (lambda () (write %load-path))))
+
+
+(load-extension "../../liblepton/src/liblepton" "liblepton_init")
+(define with-toplevel (@@ (lepton core toplevel) %with-toplevel))
+(define make-toplevel (@@ (lepton core toplevel) %make-toplevel))
 
 
 (define (report s port)
