@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -173,7 +173,6 @@ struct st_gschem_toplevel {
   int event_state;                      /* Current event state */
   int min_zoom;                         /* minimum zoom factor */
   int max_zoom;                         /* maximum zoom factor */
-  int inside_redraw;                    /* complex vs list redrawing */
   int drawbounding_action_mode;         /* outline vs bounding box */
   int last_drawb_mode;                  /* last above mode */
   int CONTROLKEY;                       /* control key pressed? */
@@ -197,8 +196,8 @@ struct st_gschem_toplevel {
   int net_direction_mode; /* controls if the net direction mode is used */
   int net_selection_mode;  /* controls the behaviour when selecting a net */
   int net_selection_state;  /* current status of the net selecting mode */
-  int embed_complex;      /* controls if complex objects are embedded */
-  int include_complex;    /* controls if complex objects are included */
+  int embed_component;    /* controls if component objects are embedded */
+  int include_component;  /* controls if component objects are included */
   int scrollbars_flag;    /* controls if scrollbars are displayed */
   int log_window;         /* controls if the log windows mapped on startup */
   int third_button;       /* controls what the third mouse button does */
@@ -241,6 +240,8 @@ struct st_gschem_toplevel {
   int zoom_gain;          /* Percentage increase in size for a zoom-in operation */
   int scrollpan_steps;    /* Number of scroll pan events required to traverse the viewed area */
 
+  gchar* bus_ripper_symname; /* default bus ripper symbol file name */
+
   gboolean dont_invalidate;
 
   SCM smob;               /* The Scheme representation of this window */
