@@ -7,8 +7,8 @@ extern int default_net_selection_mode;
 extern int default_zoom_with_pan;
 extern int default_actionfeedback_mode;
 extern int default_do_logging;
-extern int default_embed_complex;
-extern int default_include_complex;
+extern int default_embed_component;
+extern int default_include_component;
 extern int default_snap_size;
 
 extern int default_scrollbars_flag;
@@ -22,7 +22,6 @@ extern int default_third_button;
 extern int default_third_button_cancel;
 extern int default_middle_button;
 extern int default_scroll_wheel;
-extern int default_net_consolidate;
 extern int default_file_preview;
 extern int default_enforce_hierarchy;
 extern int default_fast_mousepan;
@@ -54,3 +53,7 @@ extern int default_keyboardpan_gain;
 extern int default_select_slack_pixels;
 extern int default_zoom_gain;
 extern int default_scrollpan_steps;
+extern gboolean default_tabs_enabled;
+extern gboolean default_tabs_show_close_button;
+extern gboolean default_tabs_show_up_button;
+extern gboolean default_tabs_show_tooltips;
