@@ -147,6 +147,7 @@ SCM g_keys_options_magneticnet(SCM rest);
 SCM g_keys_options_show_log_window(SCM rest);
 SCM g_keys_options_show_coord_window(SCM rest);
 SCM g_keys_options_select_font(SCM rest);
+SCM g_keys_options_draw_grips(SCM rest);
 SCM g_keys_help_about(SCM rest);
 SCM g_keys_help_hotkeys(SCM rest);
 SCM g_keys_cancel(SCM rest);
@@ -154,53 +155,8 @@ void g_init_keys ();
 /* g_rc.c */
 void g_rc_parse_gtkrc();
 SCM g_rc_gschem_version(SCM version);
-SCM g_rc_net_direction_mode(SCM mode);
-SCM g_rc_net_selection_mode(SCM mode);
-SCM g_rc_action_feedback_mode(SCM mode);
-SCM g_rc_zoom_with_pan(SCM mode);
-SCM g_rc_logging(SCM mode);
-SCM g_rc_embed_components(SCM mode);
-SCM g_rc_text_size(SCM size);
-SCM g_rc_text_caps_style(SCM mode);
-SCM g_rc_snap_size(SCM size);
 SCM g_rc_attribute_name(SCM path);
-SCM g_rc_scrollbars(SCM mode);
-SCM g_rc_log_window(SCM mode);
-SCM g_rc_third_button(SCM mode);
-SCM g_rc_third_button_cancel(SCM mode);
-SCM g_rc_middle_button(SCM mode);
-SCM g_rc_scroll_wheel(SCM mode);
-SCM g_rc_net_consolidate(SCM mode);
-SCM g_rc_file_preview(SCM mode);
-SCM g_rc_enforce_hierarchy(SCM mode);
-SCM g_rc_fast_mousepan(SCM mode);
-SCM g_rc_continue_component_place(SCM mode);
-SCM g_rc_undo_levels(SCM levels);
-SCM g_rc_undo_control(SCM mode);
-SCM g_rc_undo_type(SCM mode);
-SCM g_rc_undo_panzoom(SCM mode);
-SCM g_rc_draw_grips(SCM mode);
-SCM g_rc_netconn_rubberband(SCM mode);
-SCM g_rc_magnetic_net_mode(SCM mode);
 SCM g_rc_add_menu(SCM menu_name, SCM menu_items);
-SCM g_rc_warp_cursor(SCM mode);
-SCM g_rc_toolbars(SCM mode);
-SCM g_rc_handleboxes(SCM mode);
-SCM g_rc_bus_ripper_size(SCM size);
-SCM g_rc_bus_ripper_type(SCM mode);
-SCM g_rc_bus_ripper_rotation(SCM mode);
-SCM g_rc_force_boundingbox(SCM mode);
-SCM g_rc_grid_mode(SCM mode);
-SCM g_rc_dots_grid_dot_size(SCM dotsize);
-SCM g_rc_dots_grid_mode(SCM mode);
-SCM g_rc_dots_grid_fixed_threshold(SCM spacing);
-SCM g_rc_mesh_grid_display_threshold(SCM spacing);
-SCM g_rc_auto_save_interval(SCM seconds);
-SCM g_rc_mousepan_gain(SCM mode);
-SCM g_rc_keyboardpan_gain(SCM mode);
-SCM g_rc_select_slack_pixels(SCM pixels);
-SCM g_rc_zoom_gain(SCM gain);
-SCM g_rc_scrollpan_steps(SCM steps);
 SCM g_rc_display_color_map (SCM scm_map);
 SCM g_rc_display_outline_color_map (SCM scm_map);
 /* g_register.c */
@@ -364,6 +320,7 @@ void i_callback_help_about(gpointer data, guint callback_action, GtkWidget *widg
 void i_callback_help_hotkeys(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_options_show_coord_window(gpointer data, guint callback_action, GtkWidget *widget);
 void i_callback_options_select_font(gpointer data, guint callback_action, GtkWidget *widget);
+void i_callback_options_draw_grips(gpointer data, guint callback_action, GtkWidget *widget);
 gboolean i_callback_close_wm(GtkWidget *widget, GdkEvent *event, gpointer data);
 /* i_vars.c */
 void i_vars_set(GschemToplevel *w_current);
@@ -422,10 +379,10 @@ void o_circle_start(GschemToplevel *w_current, int x, int y);
 void o_circle_end(GschemToplevel *w_current, int x, int y);
 void o_circle_motion(GschemToplevel *w_current, int x, int y);
 void o_circle_draw_rubber (GschemToplevel *w_current, EdaRenderer *renderer);
-/* o_complex.c */
-void o_complex_prepare_place(GschemToplevel *w_current, const CLibSymbol *sym);
-void o_complex_place_changed_run_hook(GschemToplevel *w_current);
-void o_complex_translate_all(GschemToplevel *w_current, int offset);
+/* o_component.c */
+void o_component_prepare_place (GschemToplevel *w_current, const CLibSymbol *sym);
+void o_component_place_changed_run_hook (GschemToplevel *w_current);
+void o_component_translate_all (GschemToplevel *w_current, int offset);
 /* o_copy.c */
 void o_copy_start(GschemToplevel *w_current, int x, int y);
 void o_copy_end(GschemToplevel *w_current);
@@ -689,9 +646,7 @@ gboolean x_show_uri (GschemToplevel *w_current, const gchar *buf, GError **err);
 GtkWidget *get_main_menu(GschemToplevel *w_current);
 GtkWidget *get_main_popup(GschemToplevel *w_current);
 gint do_popup(GschemToplevel *w_current, GdkEventButton *event);
-void x_menus_sensitivity(GschemToplevel *w_current, const char *buf, int flag);
-void x_menus_popup_sensitivity(GschemToplevel *w_current, const char *buf, int flag);
-void x_menu_attach_recent_files_submenu(GschemToplevel *w_current);
+void x_menus_sensitivity (GtkWidget* menu, const gchar* action_name, gboolean sensitive);
 /* x_multiattrib.c */
 void x_multiattrib_open (GschemToplevel *w_current);
 void x_multiattrib_close (GschemToplevel *w_current);
