@@ -4,12 +4,12 @@
 ;
 
 (use-modules (gschem deprecated)
+             (schematic action)
+             (schematic builtins)
              (schematic gui keymap)
              (schematic gui stroke)
              (schematic netlist)
-             (gschem builtins)
-             (gschem action)
-             (geda config))
+             (lepton config))
 
 
 ; gschem-version string
@@ -23,7 +23,6 @@
 
 
 ( load-from-path "conf/schematic/deprecated.scm" )
-( load-from-path "conf/schematic/options.scm"    )
 ( load-from-path "conf/schematic/attribs.scm"    )
 ( load-from-path "conf/schematic/stroke.scm"     )
 ( load-from-path "conf/schematic/keys.scm"       )
