@@ -1,6 +1,7 @@
 ;;; Lepton EDA Schematic Capture
 ;;; Copyright (C) 1998-2010 Ales Hvezda
 ;;; Copyright (C) 1998-2014 gEDA Contributors (see ChangeLog for details)
+;;; Copyright (C) 2020 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 ;;; MA 02111-1301 USA.
 
 (use-modules (ice-9 regex)
-             (geda object))
+             (lepton object))
 
 ;; --------------------------------------------------------------------------
 ;;
