@@ -2,7 +2,7 @@
 ;; Scheme API
 ;; Copyright (C) 2010-2011 Peter Brett
 ;; Copyright (C) 2010-2012 gEDA Contributors
-;; Copyright (C) 2017-2019 Lepton EDA Contributors
+;; Copyright (C) 2017-2020 Lepton EDA Contributors
 ;;
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -23,20 +23,19 @@
 ;; be used in new code.
 
 (define-module (gschem deprecated)
-
-  #:use-module (gschem core gettext)
-
-  #:use-module (geda page)
-  #:use-module (geda object)
-  #:use-module (geda attrib)
-  #:use-module (gschem window)
-  #:use-module (gschem hook)
-  #:use-module (gschem selection)
-  #:use-module (gschem attrib)
+  #:use-module (srfi srfi-1)
 
   #:use-module (geda deprecated)
 
-  #:use-module (srfi srfi-1))
+  #:use-module (lepton attrib)
+  #:use-module (lepton object)
+  #:use-module (lepton page)
+
+  #:use-module (schematic attrib)
+  #:use-module (schematic core gettext)
+  #:use-module (schematic hook)
+  #:use-module (schematic selection)
+  #:use-module (schematic window))
 
 ;; add-attribute-to-object object name value visible show
 ;;
@@ -45,7 +44,7 @@
 ;; or both of the strings "name and "value" (if neither is specified,
 ;; both are assumed).
 ;;
-;; See also add-attrib! in the (gschem attrib) module.
+;; See also add-attrib! in the (schematic attrib) module.
 (define-public (add-attribute-to-object object name value visible show)
   (add-attrib! object name value visible
                (let ((n (member "name" show))
@@ -232,7 +231,7 @@
 ;; get-selected-filename
 ;;
 ;; Returns the filename associated with the active page in the current
-;; gschem window.
+;; lepton-schematic window.
 (define-public (get-selected-filename)
   (page-filename (active-page)))
 
