@@ -1,7 +1,7 @@
 ;;; Lepton EDA Schematic Capture
 ;;; Copyright (C) 1998-2010 Ales Hvezda
 ;;; Copyright (C) 1998-2013 gEDA Contributors
-;;; Copyright (C) 2017-2019 Lepton EDA Contributors
+;;; Copyright (C) 2017-2020 Lepton EDA Contributors
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -19,8 +19,8 @@
 ;;; MA 02111-1301 USA.
 
 (define-module (schematic gui stroke)
-  #:use-module (gschem action)
-  #:use-module (gschem builtins)
+  #:use-module (schematic action)
+  #:use-module (schematic builtins)
 
   #:export (eval-stroke))
 
