@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,7 +50,7 @@ void about_dialog (GschemToplevel *w_current)
                                     PACKAGE_DOTTED_VERSION,
                                     PACKAGE_GIT_COMMIT);
 
-  logo_file = g_strconcat (w_current->toplevel->bitmap_directory,
+  logo_file = g_strconcat (BITMAP_DIRECTORY,
                            G_DIR_SEPARATOR_S, "gschem-about-logo.png", NULL);
 
   logo = gdk_pixbuf_new_from_file (logo_file, &error);
@@ -69,7 +69,12 @@ void about_dialog (GschemToplevel *w_current)
 
   gtk_about_dialog_set_name (adlg, "lepton-schematic");
   gtk_about_dialog_set_version (adlg, version_string);
-  gtk_about_dialog_set_logo (adlg, logo);
+
+  if (logo != NULL)
+  {
+    gtk_about_dialog_set_logo (adlg, logo);
+  }
+
   gtk_about_dialog_set_comments (adlg, _("Lepton Electronic Design Automation"));
 
   /*
@@ -79,7 +84,7 @@ void about_dialog (GschemToplevel *w_current)
 
   gtk_about_dialog_set_copyright (adlg,
     _("Copyright © 1998-2017 by Ales Hvezda and the respective original authors.\n"
-      "Copyright © 2017-2019 Lepton Developers.\n"
+      "Copyright © 2017-2020 Lepton Developers.\n"
       "See AUTHORS, ChangeLog files and consult 'git log' history for details."));
 
   gtk_about_dialog_set_license (adlg,
@@ -116,7 +121,11 @@ void about_dialog (GschemToplevel *w_current)
   gtk_widget_destroy (dlg);
 
   g_free (version_string);
-  g_object_unref (logo);
+
+  if (logo != NULL)
+  {
+    g_object_unref (logo);
+  }
 }
 
 /***************** End of help/about dialog box *********************/
