@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -195,6 +195,20 @@ void i_action_update_status (GschemToplevel *w_current, gboolean inside_action)
 }
 
 
+
+/*! \brief Update sensitivity of menu items according to current event state.
+ *
+ *  \param [in] w_current  GschemToplevel structure
+ *  \param [in] newstate   The new state
+ */
+static void
+update_state_menu_items (GschemToplevel* w_current, enum x_states newstate)
+{
+  x_menus_sensitivity (w_current->menubar, "&edit-select", newstate != SELECT);
+}
+
+
+
 /*! \brief Set new state, then show state field
  *
  *  \par Function Description
@@ -235,6 +249,8 @@ void i_set_state(GschemToplevel *w_current, enum x_states newstate)
       case ROTATEMODE: mode="rotate-mode"; break;
     }
 
+  update_state_menu_items (w_current, newstate);
+
   g_run_hook_action_mode (w_current, "%switch-action-mode-hook", mode);
 }
 
@@ -311,6 +327,7 @@ void i_update_toolbar(GschemToplevel *w_current)
 }
 
 
+
 /*! \brief Update sensitivity of the Edit/Paste menu item
  *
  *  \par Function Description
@@ -320,46 +337,33 @@ void i_update_toolbar(GschemToplevel *w_current)
 static void clipboard_usable_cb (int usable, void *userdata)
 {
   GschemToplevel *w_current = GSCHEM_TOPLEVEL (userdata);
-  x_menus_sensitivity (w_current, "_Edit/_Paste", usable);
+  x_menus_sensitivity (w_current->menubar,    "&clipboard-paste", usable);
+  x_menus_sensitivity (w_current->popup_menu, "&clipboard-paste", usable);
 }
 
 
 
-/*! \brief Return TRUE if at least 1 text object is selected
+/*! \brief Return the first object of type \a type if it is selected.
+ *
+ *  \param toplevel  pointer to TOPLEVEL structure
+ *  \param type      object type constant (OBJ_TEXT, OBJ_COMPONENT, etc.) (o_types.h)
  */
-static gboolean
-selected_at_least_one_text_object(GschemToplevel *w_current)
+static OBJECT*
+obj_selected (TOPLEVEL* toplevel, int type)
 {
-  OBJECT *obj;
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
-  GList *list = geda_list_get_glist(toplevel->page_current->selection_list);
+  OBJECT* result = FALSE;
+  SELECTION* selection = toplevel->page_current->selection_list;
 
-  while(list != NULL) {
-    obj = (OBJECT *) list->data;
-    if (obj->type == OBJ_TEXT)
-      return TRUE;
-    list = g_list_next(list);
-  }
-  return FALSE;
-}
-
-
-
-/*! \brief Return TRUE if at least 1 component object is selected
- */
-static gboolean
-selected_at_least_one_comp_object(GschemToplevel *w_current)
-{
-  gboolean result = FALSE;
-  TOPLEVEL* toplevel = gschem_toplevel_get_toplevel (w_current);
-  GList* selected = geda_list_get_glist (toplevel->page_current->selection_list);
-
-  for ( ; selected != NULL; selected = g_list_next (selected) )
+  GList* gl = geda_list_get_glist (selection);
+  for ( ; gl != NULL; gl = g_list_next (gl) )
   {
-    OBJECT* obj = (OBJECT*) selected->data;
-    if (obj->complex != NULL)
+    OBJECT* obj = (OBJECT*) gl->data;
+    if (obj->type == type)
     {
-      result = TRUE;
+#ifdef DEBUG
+      printf (" >> obj_selected(): obj->type: [%c]\n", obj->type);
+#endif
+      result = obj;
       break;
     }
   }
@@ -369,103 +373,115 @@ selected_at_least_one_comp_object(GschemToplevel *w_current)
 
 
 
-/*! \brief Update sensitivity of relevant menu items
+/*! \brief Return TRUE if a component with "source" attribute is selected.
  *
- *  \par Function Description
- *  Update sensitivity of relevant menu items.
+ *  \param [in] w_current  GschemToplevel structure
+ */
+static gboolean
+parent_comp_selected (TOPLEVEL* toplevel)
+{
+  gboolean result = FALSE;
+  OBJECT* obj = obj_selected (toplevel, OBJ_COMPONENT);
+
+  if (obj != NULL)
+  {
+    char* attr = o_attrib_search_attached_attribs_by_name (obj, "source", 0);
+    if (attr == NULL)
+    {
+      attr = o_attrib_search_inherited_attribs_by_name (obj, "source", 0);
+    }
+
+    result = attr != NULL;
+    g_free (attr);
+  }
+
+  return result;
+}
+
+
+
+/*! \brief Update menu items sensitivity for the main and popup menus.
  *
  *  \param [in] w_current GschemToplevel structure
  */
-void i_update_menus(GschemToplevel *w_current)
+void i_update_menus (GschemToplevel* w_current)
 {
-  gboolean have_text_selected = FALSE;
-  gboolean have_comp_selected = FALSE;
-  TOPLEVEL *toplevel = gschem_toplevel_get_toplevel (w_current);
-  /*
-   * This is very simplistic.  Right now it just disables all menu
-   * items which get greyed out when a component is not selected.
-   * Eventually what gets enabled/disabled
-   * should be based on what is in the selection list
-   */
+  g_return_if_fail (w_current != NULL);
 
-  g_assert(w_current != NULL);
-  g_assert(toplevel->page_current != NULL);
+  TOPLEVEL* toplevel = gschem_toplevel_get_toplevel (w_current);
+  g_return_if_fail (toplevel != NULL);
 
+  PAGE* page = toplevel->page_current;
+  g_return_if_fail (page != NULL);
+
+  /* update Edit->Paste sensitivity in clipboard_usable_cb():
+  */
   x_clipboard_query_usable (w_current, clipboard_usable_cb, w_current);
 
-  if (o_select_selected (w_current)) {
-    have_text_selected = selected_at_least_one_text_object(w_current);
-    have_comp_selected = selected_at_least_one_comp_object(w_current);
+  update_state_menu_items (w_current, (enum x_states) w_current->event_state);
 
-    /* since one or more things are selected, we set these TRUE */
-    /* These strings should NOT be internationalized */
-    x_menus_sensitivity(w_current, "_Edit/Cu_t", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/_Copy", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/_Delete", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Copy Mode", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Multiple Copy Mode", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Move Mode", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Rotate 90 Mode", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Mirror Mode", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Edit...", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Slot...", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Lock", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Unlock", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Embed Component/Picture", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Unembed Component/Picture", TRUE);
-    x_menus_sensitivity(w_current, "_Edit/Update Component", TRUE);
-    x_menus_sensitivity(w_current, "Hie_rarchy/_Down Schematic", TRUE);
-    x_menus_sensitivity(w_current, "Hie_rarchy/Down _Symbol", TRUE);
-    x_menus_sensitivity(w_current, "_Help/Find Component D_ocumentation",
-                        have_comp_selected);
-    x_menus_sensitivity(w_current, "A_ttributes/_Attach", TRUE);
-    x_menus_sensitivity(w_current, "A_ttributes/_Detach", TRUE);
-    x_menus_sensitivity(w_current, "A_ttributes/Show _Value", have_text_selected);
-    x_menus_sensitivity(w_current, "A_ttributes/Show _Name", have_text_selected);
-    x_menus_sensitivity(w_current, "A_ttributes/Show _Both", have_text_selected);
-    x_menus_sensitivity(w_current, "A_ttributes/_Toggle Visibility", have_text_selected);
+  gboolean selected      = o_select_selected (w_current);
+  gboolean text_selected = selected && obj_selected (toplevel, OBJ_TEXT);
+  gboolean comp_selected = selected && obj_selected (toplevel, OBJ_COMPONENT);
+  gboolean pic_selected  = selected && obj_selected (toplevel, OBJ_PICTURE);
+  gboolean embeddable    = comp_selected || pic_selected;
+  gboolean has_parent    = s_hierarchy_find_up_page (toplevel->pages, page) != NULL;
+  gboolean parent        = comp_selected && parent_comp_selected (toplevel);
 
-    /*  Menu items for hierarchy added by SDB 1.9.2005.  */
-    x_menus_popup_sensitivity(w_current, "Down Schematic", TRUE);
-    x_menus_popup_sensitivity(w_current, "Down Symbol", TRUE);
-    /* x_menus_popup_sensitivity(w_current, "/Up", TRUE); */
+  GtkWidget* mmenu = w_current->menubar;
 
-  } else {
-    /* Nothing is selected, grey these out */
-    /* These strings should NOT be internationalized */
-    x_menus_sensitivity(w_current, "_Edit/Cu_t", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/_Copy", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/_Delete", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Copy Mode", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Multiple Copy Mode", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Move Mode", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Rotate 90 Mode", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Mirror Mode", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Edit...", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Slot...", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Lock", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Unlock", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Embed Component/Picture", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Unembed Component/Picture", FALSE);
-    x_menus_sensitivity(w_current, "_Edit/Update Component", FALSE);
-    x_menus_sensitivity(w_current, "Hie_rarchy/_Down Schematic", FALSE);
-    x_menus_sensitivity(w_current, "Hie_rarchy/Down _Symbol", FALSE);
-    x_menus_sensitivity(w_current, "_Help/Find Component D_ocumentation", FALSE);
-    x_menus_sensitivity(w_current, "A_ttributes/_Attach", FALSE);
-    x_menus_sensitivity(w_current, "A_ttributes/_Detach", FALSE);
-    x_menus_sensitivity(w_current, "A_ttributes/Show _Value", FALSE);
-    x_menus_sensitivity(w_current, "A_ttributes/Show _Name", FALSE);
-    x_menus_sensitivity(w_current, "A_ttributes/Show _Both", FALSE);
-    x_menus_sensitivity(w_current, "A_ttributes/_Toggle Visibility", FALSE);
+  x_menus_sensitivity (mmenu, "&clipboard-cut", selected);
+  x_menus_sensitivity (mmenu, "&clipboard-copy", selected);
+  x_menus_sensitivity (mmenu, "&edit-delete", selected);
+  x_menus_sensitivity (mmenu, "&edit-copy", selected);
+  x_menus_sensitivity (mmenu, "&edit-mcopy", selected);
+  x_menus_sensitivity (mmenu, "&edit-move", selected);
+  x_menus_sensitivity (mmenu, "&edit-rotate-90", selected);
+  x_menus_sensitivity (mmenu, "&edit-mirror", selected);
+  x_menus_sensitivity (mmenu, "&edit-edit", selected);
+  x_menus_sensitivity (mmenu, "&edit-text", text_selected);
+  x_menus_sensitivity (mmenu, "&edit-object-properties", selected);
+  x_menus_sensitivity (mmenu, "&edit-slot", comp_selected);
+  x_menus_sensitivity (mmenu, "&edit-lock", selected);
+  x_menus_sensitivity (mmenu, "&edit-unlock", selected);
+  x_menus_sensitivity (mmenu, "&edit-embed", embeddable);
+  x_menus_sensitivity (mmenu, "&edit-unembed", embeddable);
+  x_menus_sensitivity (mmenu, "&edit-update", comp_selected);
+  x_menus_sensitivity (mmenu, "&edit-deselect", selected);
 
-    /*  Menu items for hierarchy added by SDB 1.9.2005.  */
-    x_menus_popup_sensitivity(w_current, "Down Schematic", FALSE);
-    x_menus_popup_sensitivity(w_current, "Down Symbol", FALSE);
-    /* x_menus_popup_sensitivity(w_current, "/Up", FALSE);	*/
-  }
+  x_menus_sensitivity (mmenu, "&hierarchy-down-schematic", parent);
+  x_menus_sensitivity (mmenu, "&hierarchy-down-symbol", comp_selected);
+  x_menus_sensitivity (mmenu, "&hierarchy-up", has_parent);
+
+  x_menus_sensitivity (mmenu, "&attributes-attach", selected);
+  x_menus_sensitivity (mmenu, "&attributes-detach", selected);
+  x_menus_sensitivity (mmenu, "&attributes-show-value", text_selected);
+  x_menus_sensitivity (mmenu, "&attributes-show-name", text_selected);
+  x_menus_sensitivity (mmenu, "&attributes-show-both", text_selected);
+  x_menus_sensitivity (mmenu, "&attributes-visibility-toggle", text_selected);
+
+  x_menus_sensitivity (mmenu, "&hierarchy-documentation", comp_selected);
+
+  x_menus_sensitivity (mmenu, "&page-revert", !x_window_untitled_page (page));
+
+
+  GtkWidget* pmenu = w_current->popup_menu;
+
+  x_menus_sensitivity (pmenu, "&clipboard-cut", selected);
+  x_menus_sensitivity (pmenu, "&clipboard-copy", selected);
+  x_menus_sensitivity (pmenu, "&edit-delete", selected);
+
+  x_menus_sensitivity (pmenu, "&edit-edit", selected);
+  x_menus_sensitivity (pmenu, "&edit-text", text_selected);
+  x_menus_sensitivity (pmenu, "&edit-object-properties", selected);
+
+  x_menus_sensitivity (pmenu, "&hierarchy-down-schematic", parent);
+  x_menus_sensitivity (pmenu, "&hierarchy-down-symbol", comp_selected);
+  x_menus_sensitivity (pmenu, "&hierarchy-up", has_parent);
+
+} /* i_update_menus() */
 
 
-}
 
 /*! \brief Set the main window's title
  *
