@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -839,9 +839,9 @@ DEFINE_I_CALLBACK(edit_embed)
     while (s_current != NULL) {
       o_current = (OBJECT *) s_current->data;
       g_assert (o_current != NULL);
-      if ( (o_current->type == OBJ_COMPLEX) ||
+      if ( (o_current->type == OBJ_COMPONENT) ||
 	   (o_current->type == OBJ_PICTURE) ) {
-        o_embed (toplevel, o_current);
+        o_embed (o_current);
       }
       s_current = g_list_next(s_current);
     }
@@ -881,9 +881,9 @@ DEFINE_I_CALLBACK(edit_unembed)
     while (s_current != NULL) {
       o_current = (OBJECT *) s_current->data;
       g_assert (o_current != NULL);
-      if ( (o_current->type == OBJ_COMPLEX) ||
+      if ( (o_current->type == OBJ_COMPONENT) ||
            (o_current->type == OBJ_PICTURE) ) {
-        o_unembed (toplevel, o_current);
+        o_unembed (o_current);
       }
       s_current = g_list_next(s_current);
     }
@@ -925,7 +925,7 @@ DEFINE_I_CALLBACK(edit_update)
     selection = geda_list_get_glist (toplevel->page_current->selection_list);
     for (iter = selection; iter != NULL; iter = g_list_next (iter)) {
       OBJECT *o_current = (OBJECT *) iter->data;
-      if (o_current != NULL && o_current->type == OBJ_COMPLEX) {
+      if (o_current != NULL && o_current->type == OBJ_COMPONENT) {
         selected_components = g_list_prepend (selected_components, o_current);
       }
     }
@@ -1516,6 +1516,14 @@ DEFINE_I_CALLBACK(page_revert)
   g_return_if_fail (w_current != NULL);
 
   page_current = gschem_toplevel_get_toplevel (w_current)->page_current;
+
+  /* do not revert untitled pages:
+  */
+  if (x_window_untitled_page (page_current))
+  {
+    return;
+  }
+
   filename = g_strdup (s_page_get_filename (page_current));
 
   const gchar* msg =
@@ -1525,7 +1533,8 @@ DEFINE_I_CALLBACK(page_revert)
       "\n"
       "Are you sure you want to revert this page?\n"
       "All unsaved changes in current schematic will be\n"
-      "discarded and page file will be reloaded from disk.");
+      "discarded and page file will be reloaded from disk.\n"
+      "This action will also reload all component libraries.");
 
   dialog = gtk_message_dialog_new_with_markup
     ((GtkWindow*) w_current->main_window,
@@ -2107,7 +2116,7 @@ DEFINE_I_CALLBACK(hierarchy_down_schematic)
   object = o_select_return_first_object(w_current);
 
   /* only allow going into symbols */
-  if (object == NULL || object->type != OBJ_COMPLEX)
+  if (object == NULL || object->type != OBJ_COMPONENT)
     return;
 
   parent = gschem_toplevel_get_toplevel (w_current)->page_current;
@@ -2250,21 +2259,25 @@ DEFINE_I_CALLBACK(hierarchy_down_symbol)
   OBJECT* object = o_select_return_first_object (w_current);
 
   /* only allow going into symbols */
-  if (object == NULL || object->type != OBJ_COMPLEX)
+  if (object == NULL || object->type != OBJ_COMPONENT)
     return;
 
-  s_log_message (_("Searching for symbol [%1$s]"), object->complex_basename);
+  s_log_message (_("Searching for symbol [%1$s]"), object->component_basename);
 
-  const CLibSymbol* sym = s_clib_get_symbol_by_name (object->complex_basename);
+  const CLibSymbol* sym = s_clib_get_symbol_by_name (object->component_basename);
   if (sym == NULL)
     return;
 
-  if (s_clib_symbol_get_filename (sym) == NULL)
+  gchar* fname = s_clib_symbol_get_filename (sym);
+  if (fname == NULL)
   {
     s_log_message (_("Symbol is not a real file. Symbol cannot be loaded."));
 	  return;
   }
 
+  g_free (fname);
+
+
   TOPLEVEL* toplevel = gschem_toplevel_get_toplevel (w_current);
 
   s_hierarchy_down_symbol (toplevel, sym, toplevel->page_current);
@@ -2775,6 +2788,17 @@ DEFINE_I_CALLBACK(options_select_font)
   x_widgets_show_font_select (w_current);
 }
 
+DEFINE_I_CALLBACK(options_draw_grips)
+{
+  GschemToplevel* w_current = GSCHEM_TOPLEVEL (data);
+  g_return_if_fail (w_current != NULL);
+
+  w_current->draw_grips = !w_current->draw_grips;
+
+  GschemPageView* view = gschem_toplevel_get_current_page_view (w_current);
+  gschem_page_view_invalidate_all (view);
+}
+
 /* these is a special wrapper function which cannot use the above */
 /* DEFINE_I_CALLBACK macro */
 
