@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@ void o_edit(GschemToplevel *w_current, GList *list)
 
   o_current = (OBJECT *) list->data;
   if (o_current == NULL) {
-    fprintf(stderr, _("Got an unexpected NULL in o_edit\n"));
+    fprintf (stderr, "o_edit: ERROR: Got an unexpected NULL\n");
     exit(-1);
   }
 
@@ -60,7 +60,7 @@ void o_edit(GschemToplevel *w_current, GList *list)
   switch(o_current->type) {
 
     /* also add the ability to multi attrib edit: nets, busses, pins */
-    case(OBJ_COMPLEX):
+    case(OBJ_COMPONENT):
     case(OBJ_PLACEHOLDER):
     case(OBJ_NET):
     case(OBJ_PIN):
@@ -191,7 +191,7 @@ void o_unlock(GschemToplevel *w_current)
  *  The list contains a given object and all its attributes
  *  (refdes, pinname, pinlabel, ...).
  *  There is a second pass to run the rotate hooks of non-simple objects,
- *  like pin or complex objects, for example.
+ *  like pin or component objects, for example.
  *
  *  \param [in] w_current  The GschemToplevel object.
  *  \param [in] centerx    Center x coordinate of rotation.
@@ -329,9 +329,8 @@ void o_edit_show_hidden_lowlevel (GschemToplevel *w_current,
       o_text_recreate (toplevel, o_current);
     }
 
-    if (o_current->type == OBJ_COMPLEX || o_current->type == OBJ_PLACEHOLDER) {
-      o_edit_show_hidden_lowlevel(w_current, o_current->complex->prim_objs);
-      o_current->w_bounds_valid_for = NULL;
+    if (o_current->type == OBJ_COMPONENT || o_current->type == OBJ_PLACEHOLDER) {
+      o_edit_show_hidden_lowlevel(w_current, o_current->component->prim_objs);
     }
 
     iter = g_list_next (iter);
@@ -458,18 +457,18 @@ o_update_component (GschemToplevel *w_current, OBJECT *o_current)
   const CLibSymbol *clib;
 
   g_return_val_if_fail (o_current != NULL, NULL);
-  g_return_val_if_fail (o_current->type == OBJ_COMPLEX, NULL);
-  g_return_val_if_fail (o_current->complex_basename != NULL, NULL);
+  g_return_val_if_fail (o_current->type == OBJ_COMPONENT, NULL);
+  g_return_val_if_fail (o_current->component_basename != NULL, NULL);
 
-  page = o_get_page (toplevel, o_current);
+  page = o_get_page (o_current);
 
   /* Force symbol data to be reloaded from source */
-  clib = s_clib_get_symbol_by_name (o_current->complex_basename);
+  clib = s_clib_get_symbol_by_name (o_current->component_basename);
   s_clib_symbol_invalidate_data (clib);
 
   if (clib == NULL) {
     s_log_message (_("Could not find symbol [%1$s] in library. Update failed."),
-                   o_current->complex_basename);
+                   o_current->component_basename);
     return NULL;
   }
 
@@ -477,21 +476,21 @@ o_update_component (GschemToplevel *w_current, OBJECT *o_current)
   o_selection_remove (toplevel, page->selection_list, o_current);
 
   /* Create new object and set embedded */
-  o_new = o_complex_new (toplevel, OBJ_COMPLEX, DEFAULT_COLOR,
-                         o_current->complex->x,
-                         o_current->complex->y,
-                         o_current->complex->angle,
-                         o_current->complex->mirror,
-                         clib, o_current->complex_basename,
-                         1);
-  if (o_complex_is_embedded (o_current)) {
-    o_embed (toplevel, o_new);
+  o_new = o_component_new (toplevel, OBJ_COMPONENT, DEFAULT_COLOR,
+                           o_current->component->x,
+                           o_current->component->y,
+                           o_current->component->angle,
+                           o_current->component->mirror,
+                           clib, o_current->component_basename,
+                           1);
+  if (o_component_is_embedded (o_current)) {
+    o_embed (o_new);
   }
 
-  new_attribs = o_complex_promote_attribs (toplevel, o_new);
+  new_attribs = o_component_promote_attribs (toplevel, o_new);
 
-  /* Cull any attributes from new COMPLEX that are already attached to
-   * old COMPLEX. Note that the new_attribs list is kept consistent by
+  /* Cull any attributes from new COMPONENT that are already attached to
+   * old COMPONENT. Note that the new_attribs list is kept consistent by
    * setting GList data pointers to NULL if their OBJECTs are
    * culled. At the end, the new_attribs list is updated by removing
    * all list items with NULL data. This is slightly magic, but
@@ -584,7 +583,8 @@ void o_autosave_backups(GschemToplevel *w_current)
       real_filename = follow_symlinks (s_page_get_filename (p_current), NULL);
 
       if (real_filename == NULL) {
-        s_log_message (_("o_autosave_backups: Can't get the real filename of %1$s."), s_page_get_filename (p_current));
+        s_log_message ("o_autosave_backups: ");
+        s_log_message (_("Can't get the real filename of %1$s."), s_page_get_filename (p_current));
       } else {
         /* Get the directory in which the real filename lives */
         dirname = g_path_get_dirname (real_filename);
