@@ -1,6 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
- * Copyright (C) 1998-2011 gEDA Contributors (see ChangeLog for details)
+ * Copyright (C) 1998-2016 gEDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -189,26 +190,22 @@ void o_move_end(GschemToplevel *w_current)
     object = (OBJECT *) s_current->data;
 
     if (object == NULL) {
-      fprintf(stderr, _("ERROR: NULL object in o_move_end!\n"));
+      fprintf (stderr, "o_move_end: ERROR: Got an unexpected NULL\n");
       exit(-1);
     }
 
 
     switch (object->type) {
-      case (OBJ_COMPLEX):
+      case (OBJ_COMPONENT):
       case (OBJ_PLACEHOLDER):
 
-        /* TODO: Fix so we can just pass the complex to o_move_end_lowlevel,
+        /* TODO: Fix so we can just pass the component to o_move_end_lowlevel,
          * IE.. by falling through the bottom of this case statement. */
+        object->component->x = object->component->x + diff_x;
+        object->component->y = object->component->y + diff_y;
 
-        /* this next section of code is from */
-        /* o_complex_world_translate_world */
-        object->complex->x = object->complex->x + diff_x;
-        object->complex->y = object->complex->y + diff_y;
-
-        o_move_end_lowlevel_glist (w_current, object->complex->prim_objs,
+        o_move_end_lowlevel_glist (w_current, object->component->prim_objs,
                                    diff_x, diff_y);
-        object->w_bounds_valid_for = NULL;
         break;
 
       default:
@@ -647,9 +644,9 @@ void o_move_prep_rubberband(GschemToplevel *w_current)
         o_move_check_endpoint (w_current, object);
         break;
 
-      case (OBJ_COMPLEX):
+      case (OBJ_COMPONENT):
       case (OBJ_PLACEHOLDER):
-        for (iter = object->complex->prim_objs;
+        for (iter = object->component->prim_objs;
              iter != NULL; iter = g_list_next (iter)) {
           o_current = (OBJECT*) iter->data;
 
@@ -725,7 +722,6 @@ void o_move_end_rubberband (GschemToplevel *w_current,
         continue;
       }
 
-      object->w_bounds_valid_for = NULL;
       s_conn_update_object (page, object);
       *objects = g_list_append (*objects, object);
     }
