@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -769,7 +769,7 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
   int first, second;
   int made_changes = FALSE;
   const int ripper_size = w_current->bus_ripper_size;
-  int complex_angle = 0;
+  int component_angle = 0;
   const CLibSymbol *rippersym = NULL;
 
   GschemPageView *page_view = gschem_toplevel_get_current_page_view (w_current);
@@ -863,17 +863,16 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
           if (w_current->bus_ripper_rotation == NON_SYMMETRIC) {
             /* non-symmetric */
             if (sign == 1) {
-              complex_angle = 0;
+              component_angle = 0;
             } else {
-              complex_angle = 90;
+              component_angle = 90;
             }
           } else {
             /* symmetric */
-            complex_angle = 0;
+            component_angle = 0;
           }
 
           net_obj->line->y[found_conn->whichone] -= ripper_size;
-          net_obj->w_bounds_valid_for = NULL;
           rippers[ripper_count].x[0] =
             net_obj->line->x[found_conn->whichone];
           rippers[ripper_count].y[0] =
@@ -900,17 +899,16 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
           if (w_current->bus_ripper_rotation == NON_SYMMETRIC) {
             /* non-symmetric */
             if (sign == 1) {
-              complex_angle = 270;
+              component_angle = 270;
             } else {
-              complex_angle = 180;
+              component_angle = 180;
             }
           } else {
             /* symmetric */
-            complex_angle = 180;
+            component_angle = 180;
           }
 
           net_obj->line->y[found_conn->whichone] += ripper_size;
-          net_obj->w_bounds_valid_for = NULL;
           rippers[ripper_count].x[0] =
             net_obj->line->x[found_conn->whichone];
           rippers[ripper_count].y[0] =
@@ -971,17 +969,16 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
           if (w_current->bus_ripper_rotation == NON_SYMMETRIC) {
             /* non-symmetric */
             if (sign == 1) {
-              complex_angle = 0;
+              component_angle = 0;
             } else {
-              complex_angle = 270;
+              component_angle = 270;
             }
           } else {
             /* symmetric */
-            complex_angle = 270;
+            component_angle = 270;
           }
 
           net_obj->line->x[found_conn->whichone] -= ripper_size;
-          net_obj->w_bounds_valid_for = NULL;
           rippers[ripper_count].x[0] =
             net_obj->line->x[found_conn->whichone];
           rippers[ripper_count].y[0] =
@@ -1007,17 +1004,16 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
           if (w_current->bus_ripper_rotation == NON_SYMMETRIC) {
             /* non-symmetric */
             if (sign == 1) {
-              complex_angle = 90;
+              component_angle = 90;
             } else {
-              complex_angle = 180;
+              component_angle = 180;
             }
           } else {
             /* symmetric */
-            complex_angle = 90;
+            component_angle = 90;
           }
 
           net_obj->line->x[found_conn->whichone] += ripper_size;
-          net_obj->w_bounds_valid_for = NULL;
           rippers[ripper_count].x[0] =
             net_obj->line->x[found_conn->whichone];
           rippers[ripper_count].y[0] =
@@ -1042,7 +1038,7 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
 
     if (w_current->bus_ripper_type == COMP_BUS_RIPPER) {
       GList *symlist =
-        s_clib_search (page->toplevel->bus_ripper_symname, CLIB_EXACT);
+        s_clib_search (w_current->bus_ripper_symname, CLIB_EXACT);
       if (symlist != NULL) {
         rippersym = (CLibSymbol *) symlist->data;
       }
@@ -1058,17 +1054,17 @@ int o_net_add_busrippers(GschemToplevel *w_current, OBJECT *net_obj,
       } else {
 
         if (rippersym != NULL) {
-          new_obj = o_complex_new (page->toplevel, OBJ_COMPLEX, DEFAULT_COLOR,
-                                   rippers[i].x[0], rippers[i].y[0],
-                                   complex_angle, 0,
-                                   rippersym,
-                                   page->toplevel->bus_ripper_symname, 1);
+          new_obj = o_component_new (page->toplevel, OBJ_COMPONENT, DEFAULT_COLOR,
+                                     rippers[i].x[0], rippers[i].y[0],
+                                     component_angle, 0,
+                                     rippersym,
+                                     w_current->bus_ripper_symname, 1);
           s_page_append_list (page->toplevel, page,
-                              o_complex_promote_attribs (page->toplevel, new_obj));
+                              o_component_promote_attribs (page->toplevel, new_obj));
           s_page_append (page->toplevel, page, new_obj);
         } else {
           s_log_message(_("Bus ripper symbol [%1$s] was not found in any component library"),
-                        page->toplevel->bus_ripper_symname);
+                        w_current->bus_ripper_symname);
         }
       }
     }
