@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -160,8 +160,7 @@ o_undo_savestate (GschemToplevel *w_current, PAGE *page, int flag)
     /* This is where the net consolidation call would have been
      * triggered before it was removed from o_save_buffer().
      */
-    if (toplevel->net_consolidate == TRUE)
-      geda_net_object_consolidate (toplevel, page);
+    geda_net_object_consolidate (toplevel, page);
   }
 
   if (w_current->undo_type == UNDO_DISK && flag == UNDO_ALL) {
@@ -395,7 +394,7 @@ o_undo_callback (GschemToplevel *w_current, PAGE *page, int type)
   g_return_if_fail (page != NULL);
 
   if (w_current->undo_control == FALSE) {
-    s_log_message(_("Undo/Redo disabled in rc file"));
+    s_log_message(_("Undo/Redo is disabled in configuration"));
     return;
   }
 
