@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2018 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -115,15 +115,15 @@ x_compselect_callback_response (GtkDialog *dialog,
                       "behavior", &behavior,
                       NULL);
 
-        w_current->include_complex = w_current->embed_complex = 0;
+        w_current->include_component = w_current->embed_component = 0;
         switch (behavior) {
             case COMPSELECT_BEHAVIOR_REFERENCE:
               break;
             case COMPSELECT_BEHAVIOR_EMBED:
-              w_current->embed_complex   = 1;
+              w_current->embed_component = 1;
               break;
             case COMPSELECT_BEHAVIOR_INCLUDE:
-              w_current->include_complex = 1;
+              w_current->include_component = 1;
               break;
             default:
               g_assert_not_reached ();
@@ -148,7 +148,7 @@ x_compselect_callback_response (GtkDialog *dialog,
           i_action_stop (w_current);
         } else {
           /* Otherwise set the new symbol to place */
-          o_complex_prepare_place (w_current, symbol);
+          o_component_prepare_place (w_current, symbol);
         }
         break;
       }
@@ -156,7 +156,7 @@ x_compselect_callback_response (GtkDialog *dialog,
       case COMPSELECT_RESPONSE_HIDE:
         /* Response when clicking on the "hide" button */
 
-        /* If there is no component in the complex place list, set the current one */
+        /* If there is no component in the place list, set the current one */
         if (toplevel->page_current->place_list == NULL) {
           gtk_dialog_response (GTK_DIALOG (compselect),
                                COMPSELECT_RESPONSE_PLACE);
@@ -477,7 +477,7 @@ update_attributes_model (Compselect *compselect, TOPLEVEL *preview_toplevel)
                               s_page_objects (preview_toplevel->page_current));
 
   cfg = eda_config_get_context_for_path (s_page_get_filename (preview_toplevel->page_current));
-  filter_list = eda_config_get_string_list (cfg, "gschem.library",
+  filter_list = eda_config_get_string_list (cfg, "schematic.library",
                                             "component-attributes", &n, NULL);
 
   if (filter_list == NULL || (n > 0 && strcmp (filter_list[0], "*") == 0)) {
@@ -853,7 +853,7 @@ create_lib_tree_model (Compselect *compselect)
   GList *srchead, *srclist;
   PAGE *page = GSCHEM_DIALOG(compselect)->w_current->toplevel->page_current;
   EdaConfig *cfg = eda_config_get_context_for_path (s_page_get_filename (page));
-  gboolean sort = eda_config_get_boolean (cfg, "gschem.library", "sort", NULL);
+  gboolean sort = eda_config_get_boolean (cfg, "schematic.library", "sort", NULL);
 
   store = (GtkTreeStore*)gtk_tree_store_new (3, G_TYPE_POINTER,
                                                 G_TYPE_STRING,
@@ -1229,7 +1229,7 @@ create_attributes_treeview (Compselect *compselect)
 
   /* two columns for name and value of the attributes */
   renderer = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
-                                              "editable", FALSE,
+                                              "editable", TRUE,
                                               NULL));
 
   column = GTK_TREE_VIEW_COLUMN (g_object_new (GTK_TYPE_TREE_VIEW_COLUMN,
