@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -222,7 +222,7 @@ x_event_button_pressed(GschemPageView *page_view, GdkEventButton *event, GschemT
       case(MOUSEBTN_DO_REPEAT):
         g_scm_c_eval_string_protected
         (
-          "( use-modules (gschem action) )"
+          "( use-modules (schematic action) )"
           "( &repeat-last-action )"
         );
       break;
@@ -366,7 +366,7 @@ x_event_button_released (GschemPageView *page_view, GdkEventButton *event, Gsche
         o_place_rotate(w_current);
 
         if (w_current->event_state == COMPMODE) {
-          o_complex_place_changed_run_hook (w_current);
+          o_component_place_changed_run_hook (w_current);
         }
 
         if (w_current->event_state == MOVEMODE) {
