@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ x_fileselect_setup_filechooser_filters (GtkFileChooser *filechooser)
   {
     filter_sch = gtk_file_filter_new();
 
-    gtk_file_filter_set_name (filter_sch, _("Schematics"));
+    gtk_file_filter_set_name (filter_sch, _("Schematics (*.sch)"));
     gtk_file_filter_add_pattern (filter_sch, "*.sch");
 
     /* NOTE: GtkFileChooser object takes ownership of the filter:
@@ -66,7 +66,7 @@ x_fileselect_setup_filechooser_filters (GtkFileChooser *filechooser)
   {
     filter_sym = gtk_file_filter_new();
 
-    gtk_file_filter_set_name (filter_sym, _("Symbols"));
+    gtk_file_filter_set_name (filter_sym, _("Symbols (*.sym)"));
     gtk_file_filter_add_pattern (filter_sym, "*.sym");
 
     g_object_ref (G_OBJECT (filter_sym));
@@ -76,7 +76,7 @@ x_fileselect_setup_filechooser_filters (GtkFileChooser *filechooser)
   {
     filter_sch_sym = gtk_file_filter_new();
 
-    gtk_file_filter_set_name (filter_sch_sym, _("Schematics and symbols"));
+    gtk_file_filter_set_name (filter_sch_sym, _("Schematics and symbols (*.sch *.sym)"));
     gtk_file_filter_add_pattern (filter_sch_sym, "*.sym");
     gtk_file_filter_add_pattern (filter_sch_sym, "*.sch");
 
@@ -134,6 +134,92 @@ x_fileselect_setup_filechooser_filters (GtkFileChooser *filechooser)
 
 
 
+/*! \brief Replace last 3 chars in filename with \a suffix and get basename
+ *
+ *  \par Function Description
+ *  Example:
+ *  basename_switch_suffix( "/path/to/file.sch", "sym" ) => "file.sym"
+ *  Caller must g_free() the return value.
+ *
+ *  \param  path    Full file path.
+ *  \param  suffix  A new suffix.
+ *
+ *  \return File's basename with suffix replaces with \a suffix
+ */
+static gchar*
+basename_switch_suffix (const gchar* path, const gchar* suffix)
+{
+  gchar* bname = g_path_get_basename (path);
+  if (bname == NULL)
+  {
+    return NULL;
+  }
+
+  gchar* name      = (gchar*) malloc (PATH_MAX);
+  glong  len_bname = g_utf8_strlen (bname, -1);
+
+  const gsize len_suffix = 3;
+  g_utf8_strncpy (name, bname, len_bname - len_suffix);
+
+  gchar* bname_new = g_strconcat (name, suffix, NULL);
+
+#ifdef DEBUG
+  printf( " .. bname:     [%s]\n",  bname );
+  printf( " .. len_bname: [%lu]\n", len_bname );
+  printf( " .. name:      [%s]\n",  name );
+  printf( " .. bname_new: [%s]\n",  bname_new );
+#endif
+
+  g_free (name);
+  g_free (bname);
+
+  return bname_new;
+
+} /* basename_switch_suffix() */
+
+
+
+/*! \brief Dialog's "filter" property change notification handler
+ *
+ *  \par Function Description
+ *  Change filename's extension (.sch or .sym) in the "Save As"
+ *  dialog according to the currently selected filter.
+ */
+static void
+on_filter_changed (GtkFileChooserDialog* dialog, gpointer data)
+{
+  GtkFileChooser* chooser = GTK_FILE_CHOOSER (dialog);
+  GtkFileFilter*  filter  = gtk_file_chooser_get_filter (chooser);
+
+  gchar* fname = gtk_file_chooser_get_filename (chooser);
+  if (fname == NULL)
+  {
+    return;
+  }
+
+
+  gchar* bname = NULL;
+
+  if (filter == filter_sch && g_str_has_suffix (fname, ".sym"))
+  {
+    bname = basename_switch_suffix (fname, "sch");
+  }
+  else
+  if (filter == filter_sym && g_str_has_suffix (fname, ".sch"))
+  {
+    bname = basename_switch_suffix (fname, "sym");
+  }
+
+  if (bname != NULL)
+  {
+    gtk_file_chooser_set_current_name (chooser, bname);
+    g_free (bname);
+  }
+
+} /* on_filter_changed() */
+
+
+
 /*! \brief Updates the preview when the selection changes.
  *  \par Function Description
  *  This is the callback function connected to the 'update-preview'
@@ -257,7 +343,11 @@ x_fileselect_open(GschemToplevel *w_current)
 					  GTK_RESPONSE_CANCEL,
 					  -1);
 
-  x_fileselect_add_preview (GTK_FILE_CHOOSER (dialog));
+  if (w_current->file_preview)
+  {
+    x_fileselect_add_preview (GTK_FILE_CHOOSER (dialog));
+  }
+
   g_object_set (dialog,
                 /* GtkFileChooser */
                 "select-multiple", TRUE,
@@ -380,6 +470,14 @@ x_fileselect_save (GschemToplevel *w_current, PAGE* page, gboolean* result)
   }
 
 
+  /* add handler for dialog's "filter" property change notification:
+  */
+  g_signal_connect (dialog,
+                    "notify::filter",
+                    G_CALLBACK (&on_filter_changed),
+                    NULL);
+
+
   /*
    * Open "Save As.." dialog:
   */
