@@ -1,7 +1,7 @@
 /* Lepton EDA Schematic Capture
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@
  * and set 1 gschem point = 1 mil, i.e. 1000 points = 1 inch */
 #define DEFAULT_GSCHEM_PPI 1000
 
-#define CFG_GROUP_PRINTING "gschem.printing"
+#define CFG_GROUP_PRINTING "schematic.printing"
 #define CFG_KEY_PRINTING_ORIENTATION "layout"
 #define CFG_KEY_PRINTING_PAPER "paper"
 #define CFG_KEY_PRINTING_MONOCHROME "monochrome"
@@ -438,6 +438,10 @@ x_print (GschemToplevel *w_current)
   */
   gtk_print_operation_set_print_settings (print, settings);
 
+  /* enable the "paper size" and "orientation" combo boxes:
+  */
+  gtk_print_operation_set_embed_page_setup (print, TRUE);
+
 
   res = gtk_print_operation_run (print, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG,
                                  GTK_WINDOW (w_current->main_window), &err);
