@@ -2,7 +2,7 @@
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2016 gEDA Contributors
  * Copyright (C) 2016 Peter Brett <peter@peter-b.co.uk>
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -133,8 +133,6 @@ void x_window_setup (GschemToplevel *w_current)
 
   /* X related stuff */
   x_window_create_main (w_current);
-
-  x_menu_attach_recent_files_submenu(w_current);
 }
 
 /*! \todo Finish function documentation!!!
@@ -395,8 +393,8 @@ static void
 x_window_translate_response (GschemTranslateWidget *widget, gint response, GschemToplevel *w_current)
 {
   if (response == GTK_RESPONSE_OK) {
-    o_complex_translate_all (w_current,
-                             gschem_translate_widget_get_value (widget));
+    o_component_translate_all (w_current,
+                               gschem_translate_widget_get_value (widget));
   }
 
   i_set_state (w_current, SELECT);
@@ -1694,7 +1692,7 @@ untitled_filename (GschemToplevel* w_current, gboolean log_skipped)
   EdaConfig* cfg = eda_config_get_context_for_path (cwd);
 
   gchar* name = eda_config_get_string (cfg,
-                                       "gschem",
+                                       "schematic",
                                        "default-filename",
                                        NULL);
 
@@ -1767,7 +1765,7 @@ x_window_untitled_page (PAGE* page)
   if (cfg != NULL)
   {
     uname = eda_config_get_string (cfg,
-                                   "gschem",
+                                   "schematic",
                                    "default-filename",
                                    NULL);
   }
